Article class final

Inheritance

Constructors

Article({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Article
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Article
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Article
Hides the element from screen readers.
inherited
ariaLabel(String value) Article
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Article
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Article
inherited
data(String key, String value) Article
Sets a custom data attribute.
inherited
hidden([bool h = true]) Article
Hides the element from display.
inherited
id(String id) Article
Sets the element's unique identifier.
inherited
lang(String value) Article
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Article
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Article
inherited
onAnimationIteration(EventCallback handler) Article
inherited
onAnimationStart(EventCallback handler) Article
inherited
onBlur(EventCallback handler) Article
inherited
onCanPlay(EventCallback handler) Article
inherited
onCanPlayThrough(EventCallback handler) Article
inherited
onChange(EventCallback handler) Article
inherited
onClick(EventCallback handler) Article
inherited
onContextMenu(EventCallback handler) Article
inherited
onCopy(EventCallback handler) Article
inherited
onCut(EventCallback handler) Article
inherited
onDoubleClick(EventCallback handler) Article
inherited
onDrag(EventCallback handler) Article
inherited
onDragEnd(EventCallback handler) Article
inherited
onDragEnter(EventCallback handler) Article
inherited
onDragLeave(EventCallback handler) Article
inherited
onDragOver(EventCallback handler) Article
inherited
onDragStart(EventCallback handler) Article
inherited
onDrop(EventCallback handler) Article
inherited
onEnded(EventCallback handler) Article
inherited
onFocus(EventCallback handler) Article
inherited
onFocusIn(EventCallback handler) Article
inherited
onFocusOut(EventCallback handler) Article
inherited
onInput(EventCallback handler) Article
inherited
onKeyDown(EventCallback handler) Article
inherited
onKeyPress(EventCallback handler) Article
inherited
onKeyUp(EventCallback handler) Article
inherited
onLoadedData(EventCallback handler) Article
inherited
onLoadedMetadata(EventCallback handler) Article
inherited
onMouseDown(EventCallback handler) Article
inherited
onMouseEnter(EventCallback handler) Article
inherited
onMouseLeave(EventCallback handler) Article
inherited
onMouseMove(EventCallback handler) Article
inherited
onMouseOut(EventCallback handler) Article
inherited
onMouseOver(EventCallback handler) Article
inherited
onMouseUp(EventCallback handler) Article
inherited
onPaste(EventCallback handler) Article
inherited
onPause(EventCallback handler) Article
inherited
onPlay(EventCallback handler) Article
inherited
onPointerCancel(EventCallback handler) Article
inherited
onPointerDown(EventCallback handler) Article
inherited
onPointerEnter(EventCallback handler) Article
inherited
onPointerLeave(EventCallback handler) Article
inherited
onPointerMove(EventCallback handler) Article
inherited
onPointerUp(EventCallback handler) Article
inherited
onReset(EventCallback handler) Article
inherited
onScroll(EventCallback handler) Article
inherited
onSelect(EventCallback handler) Article
inherited
onSubmit(EventCallback handler) Article
inherited
onTimeUpdate(EventCallback handler) Article
inherited
onTouchCancel(EventCallback handler) Article
inherited
onTouchEnd(EventCallback handler) Article
inherited
onTouchMove(EventCallback handler) Article
inherited
onTouchStart(EventCallback handler) Article
inherited
onTransitionEnd(EventCallback handler) Article
inherited
onVolumeChange(EventCallback handler) Article
inherited
onWheel(EventCallback handler) Article
inherited
style(Map<String, String> style) Article
inherited
tabIndex(int value) Article
Sets the tab order index for keyboard navigation.
inherited
title(String value) Article
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited