B class final

Inheritance

Constructors

B({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self B
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) B
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) B
Hides the element from screen readers.
inherited
ariaLabel(String value) B
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) B
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) B
inherited
data(String key, String value) B
Sets a custom data attribute.
inherited
hidden([bool h = true]) B
Hides the element from display.
inherited
id(String id) B
Sets the element's unique identifier.
inherited
lang(String value) B
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) B
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) B
inherited
onAnimationIteration(EventCallback handler) B
inherited
onAnimationStart(EventCallback handler) B
inherited
onBlur(EventCallback handler) B
inherited
onCanPlay(EventCallback handler) B
inherited
onCanPlayThrough(EventCallback handler) B
inherited
onChange(EventCallback handler) B
inherited
onClick(EventCallback handler) B
inherited
onContextMenu(EventCallback handler) B
inherited
onCopy(EventCallback handler) B
inherited
onCut(EventCallback handler) B
inherited
onDoubleClick(EventCallback handler) B
inherited
onDrag(EventCallback handler) B
inherited
onDragEnd(EventCallback handler) B
inherited
onDragEnter(EventCallback handler) B
inherited
onDragLeave(EventCallback handler) B
inherited
onDragOver(EventCallback handler) B
inherited
onDragStart(EventCallback handler) B
inherited
onDrop(EventCallback handler) B
inherited
onEnded(EventCallback handler) B
inherited
onFocus(EventCallback handler) B
inherited
onFocusIn(EventCallback handler) B
inherited
onFocusOut(EventCallback handler) B
inherited
onInput(EventCallback handler) B
inherited
onKeyDown(EventCallback handler) B
inherited
onKeyPress(EventCallback handler) B
inherited
onKeyUp(EventCallback handler) B
inherited
onLoadedData(EventCallback handler) B
inherited
onLoadedMetadata(EventCallback handler) B
inherited
onMouseDown(EventCallback handler) B
inherited
onMouseEnter(EventCallback handler) B
inherited
onMouseLeave(EventCallback handler) B
inherited
onMouseMove(EventCallback handler) B
inherited
onMouseOut(EventCallback handler) B
inherited
onMouseOver(EventCallback handler) B
inherited
onMouseUp(EventCallback handler) B
inherited
onPaste(EventCallback handler) B
inherited
onPause(EventCallback handler) B
inherited
onPlay(EventCallback handler) B
inherited
onPointerCancel(EventCallback handler) B
inherited
onPointerDown(EventCallback handler) B
inherited
onPointerEnter(EventCallback handler) B
inherited
onPointerLeave(EventCallback handler) B
inherited
onPointerMove(EventCallback handler) B
inherited
onPointerUp(EventCallback handler) B
inherited
onReset(EventCallback handler) B
inherited
onScroll(EventCallback handler) B
inherited
onSelect(EventCallback handler) B
inherited
onSubmit(EventCallback handler) B
inherited
onTimeUpdate(EventCallback handler) B
inherited
onTouchCancel(EventCallback handler) B
inherited
onTouchEnd(EventCallback handler) B
inherited
onTouchMove(EventCallback handler) B
inherited
onTouchStart(EventCallback handler) B
inherited
onTransitionEnd(EventCallback handler) B
inherited
onVolumeChange(EventCallback handler) B
inherited
onWheel(EventCallback handler) B
inherited
style(Map<String, String> style) B
inherited
tabIndex(int value) B
Sets the tab order index for keyboard navigation.
inherited
title(String value) B
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited