Blockquote class final

Inheritance

Constructors

Blockquote({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Blockquote
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Blockquote
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Blockquote
Hides the element from screen readers.
inherited
ariaLabel(String value) Blockquote
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Blockquote
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
cite(String c) Blockquote
classes(String classes) Blockquote
inherited
data(String key, String value) Blockquote
Sets a custom data attribute.
inherited
hidden([bool h = true]) Blockquote
Hides the element from display.
inherited
id(String id) Blockquote
Sets the element's unique identifier.
inherited
lang(String value) Blockquote
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Blockquote
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Blockquote
inherited
onAnimationIteration(EventCallback handler) Blockquote
inherited
onAnimationStart(EventCallback handler) Blockquote
inherited
onBlur(EventCallback handler) Blockquote
inherited
onCanPlay(EventCallback handler) Blockquote
inherited
onCanPlayThrough(EventCallback handler) Blockquote
inherited
onChange(EventCallback handler) Blockquote
inherited
onClick(EventCallback handler) Blockquote
inherited
onContextMenu(EventCallback handler) Blockquote
inherited
onCopy(EventCallback handler) Blockquote
inherited
onCut(EventCallback handler) Blockquote
inherited
onDoubleClick(EventCallback handler) Blockquote
inherited
onDrag(EventCallback handler) Blockquote
inherited
onDragEnd(EventCallback handler) Blockquote
inherited
onDragEnter(EventCallback handler) Blockquote
inherited
onDragLeave(EventCallback handler) Blockquote
inherited
onDragOver(EventCallback handler) Blockquote
inherited
onDragStart(EventCallback handler) Blockquote
inherited
onDrop(EventCallback handler) Blockquote
inherited
onEnded(EventCallback handler) Blockquote
inherited
onFocus(EventCallback handler) Blockquote
inherited
onFocusIn(EventCallback handler) Blockquote
inherited
onFocusOut(EventCallback handler) Blockquote
inherited
onInput(EventCallback handler) Blockquote
inherited
onKeyDown(EventCallback handler) Blockquote
inherited
onKeyPress(EventCallback handler) Blockquote
inherited
onKeyUp(EventCallback handler) Blockquote
inherited
onLoadedData(EventCallback handler) Blockquote
inherited
onLoadedMetadata(EventCallback handler) Blockquote
inherited
onMouseDown(EventCallback handler) Blockquote
inherited
onMouseEnter(EventCallback handler) Blockquote
inherited
onMouseLeave(EventCallback handler) Blockquote
inherited
onMouseMove(EventCallback handler) Blockquote
inherited
onMouseOut(EventCallback handler) Blockquote
inherited
onMouseOver(EventCallback handler) Blockquote
inherited
onMouseUp(EventCallback handler) Blockquote
inherited
onPaste(EventCallback handler) Blockquote
inherited
onPause(EventCallback handler) Blockquote
inherited
onPlay(EventCallback handler) Blockquote
inherited
onPointerCancel(EventCallback handler) Blockquote
inherited
onPointerDown(EventCallback handler) Blockquote
inherited
onPointerEnter(EventCallback handler) Blockquote
inherited
onPointerLeave(EventCallback handler) Blockquote
inherited
onPointerMove(EventCallback handler) Blockquote
inherited
onPointerUp(EventCallback handler) Blockquote
inherited
onReset(EventCallback handler) Blockquote
inherited
onScroll(EventCallback handler) Blockquote
inherited
onSelect(EventCallback handler) Blockquote
inherited
onSubmit(EventCallback handler) Blockquote
inherited
onTimeUpdate(EventCallback handler) Blockquote
inherited
onTouchCancel(EventCallback handler) Blockquote
inherited
onTouchEnd(EventCallback handler) Blockquote
inherited
onTouchMove(EventCallback handler) Blockquote
inherited
onTouchStart(EventCallback handler) Blockquote
inherited
onTransitionEnd(EventCallback handler) Blockquote
inherited
onVolumeChange(EventCallback handler) Blockquote
inherited
onWheel(EventCallback handler) Blockquote
inherited
style(Map<String, String> style) Blockquote
inherited
tabIndex(int value) Blockquote
Sets the tab order index for keyboard navigation.
inherited
title(String value) Blockquote
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited