Body class final

Inheritance

Constructors

Body({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Body
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Body
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Body
Hides the element from screen readers.
inherited
ariaLabel(String value) Body
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Body
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Body
inherited
data(String key, String value) Body
Sets a custom data attribute.
inherited
hidden([bool h = true]) Body
Hides the element from display.
inherited
id(String id) Body
Sets the element's unique identifier.
inherited
lang(String value) Body
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Body
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Body
inherited
onAnimationIteration(EventCallback handler) Body
inherited
onAnimationStart(EventCallback handler) Body
inherited
onBlur(EventCallback handler) Body
inherited
onCanPlay(EventCallback handler) Body
inherited
onCanPlayThrough(EventCallback handler) Body
inherited
onChange(EventCallback handler) Body
inherited
onClick(EventCallback handler) Body
inherited
onContextMenu(EventCallback handler) Body
inherited
onCopy(EventCallback handler) Body
inherited
onCut(EventCallback handler) Body
inherited
onDoubleClick(EventCallback handler) Body
inherited
onDrag(EventCallback handler) Body
inherited
onDragEnd(EventCallback handler) Body
inherited
onDragEnter(EventCallback handler) Body
inherited
onDragLeave(EventCallback handler) Body
inherited
onDragOver(EventCallback handler) Body
inherited
onDragStart(EventCallback handler) Body
inherited
onDrop(EventCallback handler) Body
inherited
onEnded(EventCallback handler) Body
inherited
onFocus(EventCallback handler) Body
inherited
onFocusIn(EventCallback handler) Body
inherited
onFocusOut(EventCallback handler) Body
inherited
onInput(EventCallback handler) Body
inherited
onKeyDown(EventCallback handler) Body
inherited
onKeyPress(EventCallback handler) Body
inherited
onKeyUp(EventCallback handler) Body
inherited
onLoadedData(EventCallback handler) Body
inherited
onLoadedMetadata(EventCallback handler) Body
inherited
onMouseDown(EventCallback handler) Body
inherited
onMouseEnter(EventCallback handler) Body
inherited
onMouseLeave(EventCallback handler) Body
inherited
onMouseMove(EventCallback handler) Body
inherited
onMouseOut(EventCallback handler) Body
inherited
onMouseOver(EventCallback handler) Body
inherited
onMouseUp(EventCallback handler) Body
inherited
onPaste(EventCallback handler) Body
inherited
onPause(EventCallback handler) Body
inherited
onPlay(EventCallback handler) Body
inherited
onPointerCancel(EventCallback handler) Body
inherited
onPointerDown(EventCallback handler) Body
inherited
onPointerEnter(EventCallback handler) Body
inherited
onPointerLeave(EventCallback handler) Body
inherited
onPointerMove(EventCallback handler) Body
inherited
onPointerUp(EventCallback handler) Body
inherited
onReset(EventCallback handler) Body
inherited
onScroll(EventCallback handler) Body
inherited
onSelect(EventCallback handler) Body
inherited
onSubmit(EventCallback handler) Body
inherited
onTimeUpdate(EventCallback handler) Body
inherited
onTouchCancel(EventCallback handler) Body
inherited
onTouchEnd(EventCallback handler) Body
inherited
onTouchMove(EventCallback handler) Body
inherited
onTouchStart(EventCallback handler) Body
inherited
onTransitionEnd(EventCallback handler) Body
inherited
onVolumeChange(EventCallback handler) Body
inherited
onWheel(EventCallback handler) Body
inherited
style(Map<String, String> style) Body
inherited
tabIndex(int value) Body
Sets the tab order index for keyboard navigation.
inherited
title(String value) Body
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited