Button class final

Inheritance

Constructors

Button({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Button
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Button
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Button
Hides the element from screen readers.
inherited
ariaLabel(String value) Button
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Button
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Button
inherited
data(String key, String value) Button
Sets a custom data attribute.
inherited
disabled([bool d = true]) Button
form(String f) Button
formaction(String fa) Button
formmethod(String fm) Button
hidden([bool h = true]) Button
Hides the element from display.
inherited
id(String id) Button
Sets the element's unique identifier.
inherited
lang(String value) Button
Sets the language of the element's content.
inherited
name(String n) Button
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Button
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Button
inherited
onAnimationIteration(EventCallback handler) Button
inherited
onAnimationStart(EventCallback handler) Button
inherited
onBlur(EventCallback handler) Button
inherited
onCanPlay(EventCallback handler) Button
inherited
onCanPlayThrough(EventCallback handler) Button
inherited
onChange(EventCallback handler) Button
inherited
onClick(EventCallback handler) Button
inherited
onContextMenu(EventCallback handler) Button
inherited
onCopy(EventCallback handler) Button
inherited
onCut(EventCallback handler) Button
inherited
onDoubleClick(EventCallback handler) Button
inherited
onDrag(EventCallback handler) Button
inherited
onDragEnd(EventCallback handler) Button
inherited
onDragEnter(EventCallback handler) Button
inherited
onDragLeave(EventCallback handler) Button
inherited
onDragOver(EventCallback handler) Button
inherited
onDragStart(EventCallback handler) Button
inherited
onDrop(EventCallback handler) Button
inherited
onEnded(EventCallback handler) Button
inherited
onFocus(EventCallback handler) Button
inherited
onFocusIn(EventCallback handler) Button
inherited
onFocusOut(EventCallback handler) Button
inherited
onInput(EventCallback handler) Button
inherited
onKeyDown(EventCallback handler) Button
inherited
onKeyPress(EventCallback handler) Button
inherited
onKeyUp(EventCallback handler) Button
inherited
onLoadedData(EventCallback handler) Button
inherited
onLoadedMetadata(EventCallback handler) Button
inherited
onMouseDown(EventCallback handler) Button
inherited
onMouseEnter(EventCallback handler) Button
inherited
onMouseLeave(EventCallback handler) Button
inherited
onMouseMove(EventCallback handler) Button
inherited
onMouseOut(EventCallback handler) Button
inherited
onMouseOver(EventCallback handler) Button
inherited
onMouseUp(EventCallback handler) Button
inherited
onPaste(EventCallback handler) Button
inherited
onPause(EventCallback handler) Button
inherited
onPlay(EventCallback handler) Button
inherited
onPointerCancel(EventCallback handler) Button
inherited
onPointerDown(EventCallback handler) Button
inherited
onPointerEnter(EventCallback handler) Button
inherited
onPointerLeave(EventCallback handler) Button
inherited
onPointerMove(EventCallback handler) Button
inherited
onPointerUp(EventCallback handler) Button
inherited
onReset(EventCallback handler) Button
inherited
onScroll(EventCallback handler) Button
inherited
onSelect(EventCallback handler) Button
inherited
onSubmit(EventCallback handler) Button
inherited
onTimeUpdate(EventCallback handler) Button
inherited
onTouchCancel(EventCallback handler) Button
inherited
onTouchEnd(EventCallback handler) Button
inherited
onTouchMove(EventCallback handler) Button
inherited
onTouchStart(EventCallback handler) Button
inherited
onTransitionEnd(EventCallback handler) Button
inherited
onVolumeChange(EventCallback handler) Button
inherited
onWheel(EventCallback handler) Button
inherited
style(Map<String, String> style) Button
inherited
tabIndex(int value) Button
Sets the tab order index for keyboard navigation.
inherited
title(String value) Button
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
type(ButtonType t) Button
value(String v) Button

Operators

operator ==(Object other) bool
The equality operator.
inherited