Caption class final

Inheritance

Constructors

Caption({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Caption
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Caption
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Caption
Hides the element from screen readers.
inherited
ariaLabel(String value) Caption
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Caption
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Caption
inherited
data(String key, String value) Caption
Sets a custom data attribute.
inherited
hidden([bool h = true]) Caption
Hides the element from display.
inherited
id(String id) Caption
Sets the element's unique identifier.
inherited
lang(String value) Caption
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Caption
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Caption
inherited
onAnimationIteration(EventCallback handler) Caption
inherited
onAnimationStart(EventCallback handler) Caption
inherited
onBlur(EventCallback handler) Caption
inherited
onCanPlay(EventCallback handler) Caption
inherited
onCanPlayThrough(EventCallback handler) Caption
inherited
onChange(EventCallback handler) Caption
inherited
onClick(EventCallback handler) Caption
inherited
onContextMenu(EventCallback handler) Caption
inherited
onCopy(EventCallback handler) Caption
inherited
onCut(EventCallback handler) Caption
inherited
onDoubleClick(EventCallback handler) Caption
inherited
onDrag(EventCallback handler) Caption
inherited
onDragEnd(EventCallback handler) Caption
inherited
onDragEnter(EventCallback handler) Caption
inherited
onDragLeave(EventCallback handler) Caption
inherited
onDragOver(EventCallback handler) Caption
inherited
onDragStart(EventCallback handler) Caption
inherited
onDrop(EventCallback handler) Caption
inherited
onEnded(EventCallback handler) Caption
inherited
onFocus(EventCallback handler) Caption
inherited
onFocusIn(EventCallback handler) Caption
inherited
onFocusOut(EventCallback handler) Caption
inherited
onInput(EventCallback handler) Caption
inherited
onKeyDown(EventCallback handler) Caption
inherited
onKeyPress(EventCallback handler) Caption
inherited
onKeyUp(EventCallback handler) Caption
inherited
onLoadedData(EventCallback handler) Caption
inherited
onLoadedMetadata(EventCallback handler) Caption
inherited
onMouseDown(EventCallback handler) Caption
inherited
onMouseEnter(EventCallback handler) Caption
inherited
onMouseLeave(EventCallback handler) Caption
inherited
onMouseMove(EventCallback handler) Caption
inherited
onMouseOut(EventCallback handler) Caption
inherited
onMouseOver(EventCallback handler) Caption
inherited
onMouseUp(EventCallback handler) Caption
inherited
onPaste(EventCallback handler) Caption
inherited
onPause(EventCallback handler) Caption
inherited
onPlay(EventCallback handler) Caption
inherited
onPointerCancel(EventCallback handler) Caption
inherited
onPointerDown(EventCallback handler) Caption
inherited
onPointerEnter(EventCallback handler) Caption
inherited
onPointerLeave(EventCallback handler) Caption
inherited
onPointerMove(EventCallback handler) Caption
inherited
onPointerUp(EventCallback handler) Caption
inherited
onReset(EventCallback handler) Caption
inherited
onScroll(EventCallback handler) Caption
inherited
onSelect(EventCallback handler) Caption
inherited
onSubmit(EventCallback handler) Caption
inherited
onTimeUpdate(EventCallback handler) Caption
inherited
onTouchCancel(EventCallback handler) Caption
inherited
onTouchEnd(EventCallback handler) Caption
inherited
onTouchMove(EventCallback handler) Caption
inherited
onTouchStart(EventCallback handler) Caption
inherited
onTransitionEnd(EventCallback handler) Caption
inherited
onVolumeChange(EventCallback handler) Caption
inherited
onWheel(EventCallback handler) Caption
inherited
style(Map<String, String> style) Caption
inherited
tabIndex(int value) Caption
Sets the tab order index for keyboard navigation.
inherited
title(String value) Caption
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited