Cite class final

Inheritance

Constructors

Cite({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Cite
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Cite
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Cite
Hides the element from screen readers.
inherited
ariaLabel(String value) Cite
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Cite
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Cite
inherited
data(String key, String value) Cite
Sets a custom data attribute.
inherited
hidden([bool h = true]) Cite
Hides the element from display.
inherited
id(String id) Cite
Sets the element's unique identifier.
inherited
lang(String value) Cite
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Cite
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Cite
inherited
onAnimationIteration(EventCallback handler) Cite
inherited
onAnimationStart(EventCallback handler) Cite
inherited
onBlur(EventCallback handler) Cite
inherited
onCanPlay(EventCallback handler) Cite
inherited
onCanPlayThrough(EventCallback handler) Cite
inherited
onChange(EventCallback handler) Cite
inherited
onClick(EventCallback handler) Cite
inherited
onContextMenu(EventCallback handler) Cite
inherited
onCopy(EventCallback handler) Cite
inherited
onCut(EventCallback handler) Cite
inherited
onDoubleClick(EventCallback handler) Cite
inherited
onDrag(EventCallback handler) Cite
inherited
onDragEnd(EventCallback handler) Cite
inherited
onDragEnter(EventCallback handler) Cite
inherited
onDragLeave(EventCallback handler) Cite
inherited
onDragOver(EventCallback handler) Cite
inherited
onDragStart(EventCallback handler) Cite
inherited
onDrop(EventCallback handler) Cite
inherited
onEnded(EventCallback handler) Cite
inherited
onFocus(EventCallback handler) Cite
inherited
onFocusIn(EventCallback handler) Cite
inherited
onFocusOut(EventCallback handler) Cite
inherited
onInput(EventCallback handler) Cite
inherited
onKeyDown(EventCallback handler) Cite
inherited
onKeyPress(EventCallback handler) Cite
inherited
onKeyUp(EventCallback handler) Cite
inherited
onLoadedData(EventCallback handler) Cite
inherited
onLoadedMetadata(EventCallback handler) Cite
inherited
onMouseDown(EventCallback handler) Cite
inherited
onMouseEnter(EventCallback handler) Cite
inherited
onMouseLeave(EventCallback handler) Cite
inherited
onMouseMove(EventCallback handler) Cite
inherited
onMouseOut(EventCallback handler) Cite
inherited
onMouseOver(EventCallback handler) Cite
inherited
onMouseUp(EventCallback handler) Cite
inherited
onPaste(EventCallback handler) Cite
inherited
onPause(EventCallback handler) Cite
inherited
onPlay(EventCallback handler) Cite
inherited
onPointerCancel(EventCallback handler) Cite
inherited
onPointerDown(EventCallback handler) Cite
inherited
onPointerEnter(EventCallback handler) Cite
inherited
onPointerLeave(EventCallback handler) Cite
inherited
onPointerMove(EventCallback handler) Cite
inherited
onPointerUp(EventCallback handler) Cite
inherited
onReset(EventCallback handler) Cite
inherited
onScroll(EventCallback handler) Cite
inherited
onSelect(EventCallback handler) Cite
inherited
onSubmit(EventCallback handler) Cite
inherited
onTimeUpdate(EventCallback handler) Cite
inherited
onTouchCancel(EventCallback handler) Cite
inherited
onTouchEnd(EventCallback handler) Cite
inherited
onTouchMove(EventCallback handler) Cite
inherited
onTouchStart(EventCallback handler) Cite
inherited
onTransitionEnd(EventCallback handler) Cite
inherited
onVolumeChange(EventCallback handler) Cite
inherited
onWheel(EventCallback handler) Cite
inherited
style(Map<String, String> style) Cite
inherited
tabIndex(int value) Cite
Sets the tab order index for keyboard navigation.
inherited
title(String value) Cite
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited