Colgroup class final

Inheritance

Constructors

Colgroup({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Colgroup
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Colgroup
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Colgroup
Hides the element from screen readers.
inherited
ariaLabel(String value) Colgroup
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Colgroup
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Colgroup
inherited
data(String key, String value) Colgroup
Sets a custom data attribute.
inherited
hidden([bool h = true]) Colgroup
Hides the element from display.
inherited
id(String id) Colgroup
Sets the element's unique identifier.
inherited
lang(String value) Colgroup
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Colgroup
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Colgroup
inherited
onAnimationIteration(EventCallback handler) Colgroup
inherited
onAnimationStart(EventCallback handler) Colgroup
inherited
onBlur(EventCallback handler) Colgroup
inherited
onCanPlay(EventCallback handler) Colgroup
inherited
onCanPlayThrough(EventCallback handler) Colgroup
inherited
onChange(EventCallback handler) Colgroup
inherited
onClick(EventCallback handler) Colgroup
inherited
onContextMenu(EventCallback handler) Colgroup
inherited
onCopy(EventCallback handler) Colgroup
inherited
onCut(EventCallback handler) Colgroup
inherited
onDoubleClick(EventCallback handler) Colgroup
inherited
onDrag(EventCallback handler) Colgroup
inherited
onDragEnd(EventCallback handler) Colgroup
inherited
onDragEnter(EventCallback handler) Colgroup
inherited
onDragLeave(EventCallback handler) Colgroup
inherited
onDragOver(EventCallback handler) Colgroup
inherited
onDragStart(EventCallback handler) Colgroup
inherited
onDrop(EventCallback handler) Colgroup
inherited
onEnded(EventCallback handler) Colgroup
inherited
onFocus(EventCallback handler) Colgroup
inherited
onFocusIn(EventCallback handler) Colgroup
inherited
onFocusOut(EventCallback handler) Colgroup
inherited
onInput(EventCallback handler) Colgroup
inherited
onKeyDown(EventCallback handler) Colgroup
inherited
onKeyPress(EventCallback handler) Colgroup
inherited
onKeyUp(EventCallback handler) Colgroup
inherited
onLoadedData(EventCallback handler) Colgroup
inherited
onLoadedMetadata(EventCallback handler) Colgroup
inherited
onMouseDown(EventCallback handler) Colgroup
inherited
onMouseEnter(EventCallback handler) Colgroup
inherited
onMouseLeave(EventCallback handler) Colgroup
inherited
onMouseMove(EventCallback handler) Colgroup
inherited
onMouseOut(EventCallback handler) Colgroup
inherited
onMouseOver(EventCallback handler) Colgroup
inherited
onMouseUp(EventCallback handler) Colgroup
inherited
onPaste(EventCallback handler) Colgroup
inherited
onPause(EventCallback handler) Colgroup
inherited
onPlay(EventCallback handler) Colgroup
inherited
onPointerCancel(EventCallback handler) Colgroup
inherited
onPointerDown(EventCallback handler) Colgroup
inherited
onPointerEnter(EventCallback handler) Colgroup
inherited
onPointerLeave(EventCallback handler) Colgroup
inherited
onPointerMove(EventCallback handler) Colgroup
inherited
onPointerUp(EventCallback handler) Colgroup
inherited
onReset(EventCallback handler) Colgroup
inherited
onScroll(EventCallback handler) Colgroup
inherited
onSelect(EventCallback handler) Colgroup
inherited
onSubmit(EventCallback handler) Colgroup
inherited
onTimeUpdate(EventCallback handler) Colgroup
inherited
onTouchCancel(EventCallback handler) Colgroup
inherited
onTouchEnd(EventCallback handler) Colgroup
inherited
onTouchMove(EventCallback handler) Colgroup
inherited
onTouchStart(EventCallback handler) Colgroup
inherited
onTransitionEnd(EventCallback handler) Colgroup
inherited
onVolumeChange(EventCallback handler) Colgroup
inherited
onWheel(EventCallback handler) Colgroup
inherited
span(int s) Colgroup
style(Map<String, String> style) Colgroup
inherited
tabIndex(int value) Colgroup
Sets the tab order index for keyboard navigation.
inherited
title(String value) Colgroup
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited