Del class final

Inheritance

Constructors

Del({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Del
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Del
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Del
Hides the element from screen readers.
inherited
ariaLabel(String value) Del
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Del
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
cite(String c) Del
classes(String classes) Del
inherited
data(String key, String value) Del
Sets a custom data attribute.
inherited
datetime(String dt) Del
hidden([bool h = true]) Del
Hides the element from display.
inherited
id(String id) Del
Sets the element's unique identifier.
inherited
lang(String value) Del
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Del
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Del
inherited
onAnimationIteration(EventCallback handler) Del
inherited
onAnimationStart(EventCallback handler) Del
inherited
onBlur(EventCallback handler) Del
inherited
onCanPlay(EventCallback handler) Del
inherited
onCanPlayThrough(EventCallback handler) Del
inherited
onChange(EventCallback handler) Del
inherited
onClick(EventCallback handler) Del
inherited
onContextMenu(EventCallback handler) Del
inherited
onCopy(EventCallback handler) Del
inherited
onCut(EventCallback handler) Del
inherited
onDoubleClick(EventCallback handler) Del
inherited
onDrag(EventCallback handler) Del
inherited
onDragEnd(EventCallback handler) Del
inherited
onDragEnter(EventCallback handler) Del
inherited
onDragLeave(EventCallback handler) Del
inherited
onDragOver(EventCallback handler) Del
inherited
onDragStart(EventCallback handler) Del
inherited
onDrop(EventCallback handler) Del
inherited
onEnded(EventCallback handler) Del
inherited
onFocus(EventCallback handler) Del
inherited
onFocusIn(EventCallback handler) Del
inherited
onFocusOut(EventCallback handler) Del
inherited
onInput(EventCallback handler) Del
inherited
onKeyDown(EventCallback handler) Del
inherited
onKeyPress(EventCallback handler) Del
inherited
onKeyUp(EventCallback handler) Del
inherited
onLoadedData(EventCallback handler) Del
inherited
onLoadedMetadata(EventCallback handler) Del
inherited
onMouseDown(EventCallback handler) Del
inherited
onMouseEnter(EventCallback handler) Del
inherited
onMouseLeave(EventCallback handler) Del
inherited
onMouseMove(EventCallback handler) Del
inherited
onMouseOut(EventCallback handler) Del
inherited
onMouseOver(EventCallback handler) Del
inherited
onMouseUp(EventCallback handler) Del
inherited
onPaste(EventCallback handler) Del
inherited
onPause(EventCallback handler) Del
inherited
onPlay(EventCallback handler) Del
inherited
onPointerCancel(EventCallback handler) Del
inherited
onPointerDown(EventCallback handler) Del
inherited
onPointerEnter(EventCallback handler) Del
inherited
onPointerLeave(EventCallback handler) Del
inherited
onPointerMove(EventCallback handler) Del
inherited
onPointerUp(EventCallback handler) Del
inherited
onReset(EventCallback handler) Del
inherited
onScroll(EventCallback handler) Del
inherited
onSelect(EventCallback handler) Del
inherited
onSubmit(EventCallback handler) Del
inherited
onTimeUpdate(EventCallback handler) Del
inherited
onTouchCancel(EventCallback handler) Del
inherited
onTouchEnd(EventCallback handler) Del
inherited
onTouchMove(EventCallback handler) Del
inherited
onTouchStart(EventCallback handler) Del
inherited
onTransitionEnd(EventCallback handler) Del
inherited
onVolumeChange(EventCallback handler) Del
inherited
onWheel(EventCallback handler) Del
inherited
style(Map<String, String> style) Del
inherited
tabIndex(int value) Del
Sets the tab order index for keyboard navigation.
inherited
title(String value) Del
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited