Dfn class final

Inheritance

Constructors

Dfn({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Dfn
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Dfn
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Dfn
Hides the element from screen readers.
inherited
ariaLabel(String value) Dfn
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Dfn
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Dfn
inherited
data(String key, String value) Dfn
Sets a custom data attribute.
inherited
hidden([bool h = true]) Dfn
Hides the element from display.
inherited
id(String id) Dfn
Sets the element's unique identifier.
inherited
lang(String value) Dfn
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Dfn
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Dfn
inherited
onAnimationIteration(EventCallback handler) Dfn
inherited
onAnimationStart(EventCallback handler) Dfn
inherited
onBlur(EventCallback handler) Dfn
inherited
onCanPlay(EventCallback handler) Dfn
inherited
onCanPlayThrough(EventCallback handler) Dfn
inherited
onChange(EventCallback handler) Dfn
inherited
onClick(EventCallback handler) Dfn
inherited
onContextMenu(EventCallback handler) Dfn
inherited
onCopy(EventCallback handler) Dfn
inherited
onCut(EventCallback handler) Dfn
inherited
onDoubleClick(EventCallback handler) Dfn
inherited
onDrag(EventCallback handler) Dfn
inherited
onDragEnd(EventCallback handler) Dfn
inherited
onDragEnter(EventCallback handler) Dfn
inherited
onDragLeave(EventCallback handler) Dfn
inherited
onDragOver(EventCallback handler) Dfn
inherited
onDragStart(EventCallback handler) Dfn
inherited
onDrop(EventCallback handler) Dfn
inherited
onEnded(EventCallback handler) Dfn
inherited
onFocus(EventCallback handler) Dfn
inherited
onFocusIn(EventCallback handler) Dfn
inherited
onFocusOut(EventCallback handler) Dfn
inherited
onInput(EventCallback handler) Dfn
inherited
onKeyDown(EventCallback handler) Dfn
inherited
onKeyPress(EventCallback handler) Dfn
inherited
onKeyUp(EventCallback handler) Dfn
inherited
onLoadedData(EventCallback handler) Dfn
inherited
onLoadedMetadata(EventCallback handler) Dfn
inherited
onMouseDown(EventCallback handler) Dfn
inherited
onMouseEnter(EventCallback handler) Dfn
inherited
onMouseLeave(EventCallback handler) Dfn
inherited
onMouseMove(EventCallback handler) Dfn
inherited
onMouseOut(EventCallback handler) Dfn
inherited
onMouseOver(EventCallback handler) Dfn
inherited
onMouseUp(EventCallback handler) Dfn
inherited
onPaste(EventCallback handler) Dfn
inherited
onPause(EventCallback handler) Dfn
inherited
onPlay(EventCallback handler) Dfn
inherited
onPointerCancel(EventCallback handler) Dfn
inherited
onPointerDown(EventCallback handler) Dfn
inherited
onPointerEnter(EventCallback handler) Dfn
inherited
onPointerLeave(EventCallback handler) Dfn
inherited
onPointerMove(EventCallback handler) Dfn
inherited
onPointerUp(EventCallback handler) Dfn
inherited
onReset(EventCallback handler) Dfn
inherited
onScroll(EventCallback handler) Dfn
inherited
onSelect(EventCallback handler) Dfn
inherited
onSubmit(EventCallback handler) Dfn
inherited
onTimeUpdate(EventCallback handler) Dfn
inherited
onTouchCancel(EventCallback handler) Dfn
inherited
onTouchEnd(EventCallback handler) Dfn
inherited
onTouchMove(EventCallback handler) Dfn
inherited
onTouchStart(EventCallback handler) Dfn
inherited
onTransitionEnd(EventCallback handler) Dfn
inherited
onVolumeChange(EventCallback handler) Dfn
inherited
onWheel(EventCallback handler) Dfn
inherited
style(Map<String, String> style) Dfn
inherited
tabIndex(int value) Dfn
Sets the tab order index for keyboard navigation.
inherited
title(String value) Dfn
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited