Dialog class final

Inheritance

Constructors

Dialog({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Dialog
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Dialog
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Dialog
Hides the element from screen readers.
inherited
ariaLabel(String value) Dialog
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Dialog
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Dialog
inherited
data(String key, String value) Dialog
Sets a custom data attribute.
inherited
hidden([bool h = true]) Dialog
Hides the element from display.
inherited
id(String id) Dialog
Sets the element's unique identifier.
inherited
lang(String value) Dialog
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Dialog
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Dialog
inherited
onAnimationIteration(EventCallback handler) Dialog
inherited
onAnimationStart(EventCallback handler) Dialog
inherited
onBlur(EventCallback handler) Dialog
inherited
onCanPlay(EventCallback handler) Dialog
inherited
onCanPlayThrough(EventCallback handler) Dialog
inherited
onChange(EventCallback handler) Dialog
inherited
onClick(EventCallback handler) Dialog
inherited
onContextMenu(EventCallback handler) Dialog
inherited
onCopy(EventCallback handler) Dialog
inherited
onCut(EventCallback handler) Dialog
inherited
onDoubleClick(EventCallback handler) Dialog
inherited
onDrag(EventCallback handler) Dialog
inherited
onDragEnd(EventCallback handler) Dialog
inherited
onDragEnter(EventCallback handler) Dialog
inherited
onDragLeave(EventCallback handler) Dialog
inherited
onDragOver(EventCallback handler) Dialog
inherited
onDragStart(EventCallback handler) Dialog
inherited
onDrop(EventCallback handler) Dialog
inherited
onEnded(EventCallback handler) Dialog
inherited
onFocus(EventCallback handler) Dialog
inherited
onFocusIn(EventCallback handler) Dialog
inherited
onFocusOut(EventCallback handler) Dialog
inherited
onInput(EventCallback handler) Dialog
inherited
onKeyDown(EventCallback handler) Dialog
inherited
onKeyPress(EventCallback handler) Dialog
inherited
onKeyUp(EventCallback handler) Dialog
inherited
onLoadedData(EventCallback handler) Dialog
inherited
onLoadedMetadata(EventCallback handler) Dialog
inherited
onMouseDown(EventCallback handler) Dialog
inherited
onMouseEnter(EventCallback handler) Dialog
inherited
onMouseLeave(EventCallback handler) Dialog
inherited
onMouseMove(EventCallback handler) Dialog
inherited
onMouseOut(EventCallback handler) Dialog
inherited
onMouseOver(EventCallback handler) Dialog
inherited
onMouseUp(EventCallback handler) Dialog
inherited
onPaste(EventCallback handler) Dialog
inherited
onPause(EventCallback handler) Dialog
inherited
onPlay(EventCallback handler) Dialog
inherited
onPointerCancel(EventCallback handler) Dialog
inherited
onPointerDown(EventCallback handler) Dialog
inherited
onPointerEnter(EventCallback handler) Dialog
inherited
onPointerLeave(EventCallback handler) Dialog
inherited
onPointerMove(EventCallback handler) Dialog
inherited
onPointerUp(EventCallback handler) Dialog
inherited
onReset(EventCallback handler) Dialog
inherited
onScroll(EventCallback handler) Dialog
inherited
onSelect(EventCallback handler) Dialog
inherited
onSubmit(EventCallback handler) Dialog
inherited
onTimeUpdate(EventCallback handler) Dialog
inherited
onTouchCancel(EventCallback handler) Dialog
inherited
onTouchEnd(EventCallback handler) Dialog
inherited
onTouchMove(EventCallback handler) Dialog
inherited
onTouchStart(EventCallback handler) Dialog
inherited
onTransitionEnd(EventCallback handler) Dialog
inherited
onVolumeChange(EventCallback handler) Dialog
inherited
onWheel(EventCallback handler) Dialog
inherited
open([bool o = true]) Dialog
style(Map<String, String> style) Dialog
inherited
tabIndex(int value) Dialog
Sets the tab order index for keyboard navigation.
inherited
title(String value) Dialog
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited