Div class final

Inheritance

Constructors

Div({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Div
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Div
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Div
Hides the element from screen readers.
inherited
ariaLabel(String value) Div
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Div
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Div
inherited
data(String key, String value) Div
Sets a custom data attribute.
inherited
hidden([bool h = true]) Div
Hides the element from display.
inherited
id(String id) Div
Sets the element's unique identifier.
inherited
lang(String value) Div
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Div
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Div
inherited
onAnimationIteration(EventCallback handler) Div
inherited
onAnimationStart(EventCallback handler) Div
inherited
onBlur(EventCallback handler) Div
inherited
onCanPlay(EventCallback handler) Div
inherited
onCanPlayThrough(EventCallback handler) Div
inherited
onChange(EventCallback handler) Div
inherited
onClick(EventCallback handler) Div
inherited
onContextMenu(EventCallback handler) Div
inherited
onCopy(EventCallback handler) Div
inherited
onCut(EventCallback handler) Div
inherited
onDoubleClick(EventCallback handler) Div
inherited
onDrag(EventCallback handler) Div
inherited
onDragEnd(EventCallback handler) Div
inherited
onDragEnter(EventCallback handler) Div
inherited
onDragLeave(EventCallback handler) Div
inherited
onDragOver(EventCallback handler) Div
inherited
onDragStart(EventCallback handler) Div
inherited
onDrop(EventCallback handler) Div
inherited
onEnded(EventCallback handler) Div
inherited
onFocus(EventCallback handler) Div
inherited
onFocusIn(EventCallback handler) Div
inherited
onFocusOut(EventCallback handler) Div
inherited
onInput(EventCallback handler) Div
inherited
onKeyDown(EventCallback handler) Div
inherited
onKeyPress(EventCallback handler) Div
inherited
onKeyUp(EventCallback handler) Div
inherited
onLoadedData(EventCallback handler) Div
inherited
onLoadedMetadata(EventCallback handler) Div
inherited
onMouseDown(EventCallback handler) Div
inherited
onMouseEnter(EventCallback handler) Div
inherited
onMouseLeave(EventCallback handler) Div
inherited
onMouseMove(EventCallback handler) Div
inherited
onMouseOut(EventCallback handler) Div
inherited
onMouseOver(EventCallback handler) Div
inherited
onMouseUp(EventCallback handler) Div
inherited
onPaste(EventCallback handler) Div
inherited
onPause(EventCallback handler) Div
inherited
onPlay(EventCallback handler) Div
inherited
onPointerCancel(EventCallback handler) Div
inherited
onPointerDown(EventCallback handler) Div
inherited
onPointerEnter(EventCallback handler) Div
inherited
onPointerLeave(EventCallback handler) Div
inherited
onPointerMove(EventCallback handler) Div
inherited
onPointerUp(EventCallback handler) Div
inherited
onReset(EventCallback handler) Div
inherited
onScroll(EventCallback handler) Div
inherited
onSelect(EventCallback handler) Div
inherited
onSubmit(EventCallback handler) Div
inherited
onTimeUpdate(EventCallback handler) Div
inherited
onTouchCancel(EventCallback handler) Div
inherited
onTouchEnd(EventCallback handler) Div
inherited
onTouchMove(EventCallback handler) Div
inherited
onTouchStart(EventCallback handler) Div
inherited
onTransitionEnd(EventCallback handler) Div
inherited
onVolumeChange(EventCallback handler) Div
inherited
onWheel(EventCallback handler) Div
inherited
style(Map<String, String> style) Div
inherited
tabIndex(int value) Div
Sets the tab order index for keyboard navigation.
inherited
title(String value) Div
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited