Figcaption class final

Inheritance

Constructors

Figcaption({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Figcaption
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Figcaption
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Figcaption
Hides the element from screen readers.
inherited
ariaLabel(String value) Figcaption
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Figcaption
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Figcaption
inherited
data(String key, String value) Figcaption
Sets a custom data attribute.
inherited
hidden([bool h = true]) Figcaption
Hides the element from display.
inherited
id(String id) Figcaption
Sets the element's unique identifier.
inherited
lang(String value) Figcaption
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Figcaption
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Figcaption
inherited
onAnimationIteration(EventCallback handler) Figcaption
inherited
onAnimationStart(EventCallback handler) Figcaption
inherited
onBlur(EventCallback handler) Figcaption
inherited
onCanPlay(EventCallback handler) Figcaption
inherited
onCanPlayThrough(EventCallback handler) Figcaption
inherited
onChange(EventCallback handler) Figcaption
inherited
onClick(EventCallback handler) Figcaption
inherited
onContextMenu(EventCallback handler) Figcaption
inherited
onCopy(EventCallback handler) Figcaption
inherited
onCut(EventCallback handler) Figcaption
inherited
onDoubleClick(EventCallback handler) Figcaption
inherited
onDrag(EventCallback handler) Figcaption
inherited
onDragEnd(EventCallback handler) Figcaption
inherited
onDragEnter(EventCallback handler) Figcaption
inherited
onDragLeave(EventCallback handler) Figcaption
inherited
onDragOver(EventCallback handler) Figcaption
inherited
onDragStart(EventCallback handler) Figcaption
inherited
onDrop(EventCallback handler) Figcaption
inherited
onEnded(EventCallback handler) Figcaption
inherited
onFocus(EventCallback handler) Figcaption
inherited
onFocusIn(EventCallback handler) Figcaption
inherited
onFocusOut(EventCallback handler) Figcaption
inherited
onInput(EventCallback handler) Figcaption
inherited
onKeyDown(EventCallback handler) Figcaption
inherited
onKeyPress(EventCallback handler) Figcaption
inherited
onKeyUp(EventCallback handler) Figcaption
inherited
onLoadedData(EventCallback handler) Figcaption
inherited
onLoadedMetadata(EventCallback handler) Figcaption
inherited
onMouseDown(EventCallback handler) Figcaption
inherited
onMouseEnter(EventCallback handler) Figcaption
inherited
onMouseLeave(EventCallback handler) Figcaption
inherited
onMouseMove(EventCallback handler) Figcaption
inherited
onMouseOut(EventCallback handler) Figcaption
inherited
onMouseOver(EventCallback handler) Figcaption
inherited
onMouseUp(EventCallback handler) Figcaption
inherited
onPaste(EventCallback handler) Figcaption
inherited
onPause(EventCallback handler) Figcaption
inherited
onPlay(EventCallback handler) Figcaption
inherited
onPointerCancel(EventCallback handler) Figcaption
inherited
onPointerDown(EventCallback handler) Figcaption
inherited
onPointerEnter(EventCallback handler) Figcaption
inherited
onPointerLeave(EventCallback handler) Figcaption
inherited
onPointerMove(EventCallback handler) Figcaption
inherited
onPointerUp(EventCallback handler) Figcaption
inherited
onReset(EventCallback handler) Figcaption
inherited
onScroll(EventCallback handler) Figcaption
inherited
onSelect(EventCallback handler) Figcaption
inherited
onSubmit(EventCallback handler) Figcaption
inherited
onTimeUpdate(EventCallback handler) Figcaption
inherited
onTouchCancel(EventCallback handler) Figcaption
inherited
onTouchEnd(EventCallback handler) Figcaption
inherited
onTouchMove(EventCallback handler) Figcaption
inherited
onTouchStart(EventCallback handler) Figcaption
inherited
onTransitionEnd(EventCallback handler) Figcaption
inherited
onVolumeChange(EventCallback handler) Figcaption
inherited
onWheel(EventCallback handler) Figcaption
inherited
style(Map<String, String> style) Figcaption
inherited
tabIndex(int value) Figcaption
Sets the tab order index for keyboard navigation.
inherited
title(String value) Figcaption
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited