Figure class final

Inheritance

Constructors

Figure({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Figure
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Figure
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Figure
Hides the element from screen readers.
inherited
ariaLabel(String value) Figure
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Figure
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Figure
inherited
data(String key, String value) Figure
Sets a custom data attribute.
inherited
hidden([bool h = true]) Figure
Hides the element from display.
inherited
id(String id) Figure
Sets the element's unique identifier.
inherited
lang(String value) Figure
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Figure
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Figure
inherited
onAnimationIteration(EventCallback handler) Figure
inherited
onAnimationStart(EventCallback handler) Figure
inherited
onBlur(EventCallback handler) Figure
inherited
onCanPlay(EventCallback handler) Figure
inherited
onCanPlayThrough(EventCallback handler) Figure
inherited
onChange(EventCallback handler) Figure
inherited
onClick(EventCallback handler) Figure
inherited
onContextMenu(EventCallback handler) Figure
inherited
onCopy(EventCallback handler) Figure
inherited
onCut(EventCallback handler) Figure
inherited
onDoubleClick(EventCallback handler) Figure
inherited
onDrag(EventCallback handler) Figure
inherited
onDragEnd(EventCallback handler) Figure
inherited
onDragEnter(EventCallback handler) Figure
inherited
onDragLeave(EventCallback handler) Figure
inherited
onDragOver(EventCallback handler) Figure
inherited
onDragStart(EventCallback handler) Figure
inherited
onDrop(EventCallback handler) Figure
inherited
onEnded(EventCallback handler) Figure
inherited
onFocus(EventCallback handler) Figure
inherited
onFocusIn(EventCallback handler) Figure
inherited
onFocusOut(EventCallback handler) Figure
inherited
onInput(EventCallback handler) Figure
inherited
onKeyDown(EventCallback handler) Figure
inherited
onKeyPress(EventCallback handler) Figure
inherited
onKeyUp(EventCallback handler) Figure
inherited
onLoadedData(EventCallback handler) Figure
inherited
onLoadedMetadata(EventCallback handler) Figure
inherited
onMouseDown(EventCallback handler) Figure
inherited
onMouseEnter(EventCallback handler) Figure
inherited
onMouseLeave(EventCallback handler) Figure
inherited
onMouseMove(EventCallback handler) Figure
inherited
onMouseOut(EventCallback handler) Figure
inherited
onMouseOver(EventCallback handler) Figure
inherited
onMouseUp(EventCallback handler) Figure
inherited
onPaste(EventCallback handler) Figure
inherited
onPause(EventCallback handler) Figure
inherited
onPlay(EventCallback handler) Figure
inherited
onPointerCancel(EventCallback handler) Figure
inherited
onPointerDown(EventCallback handler) Figure
inherited
onPointerEnter(EventCallback handler) Figure
inherited
onPointerLeave(EventCallback handler) Figure
inherited
onPointerMove(EventCallback handler) Figure
inherited
onPointerUp(EventCallback handler) Figure
inherited
onReset(EventCallback handler) Figure
inherited
onScroll(EventCallback handler) Figure
inherited
onSelect(EventCallback handler) Figure
inherited
onSubmit(EventCallback handler) Figure
inherited
onTimeUpdate(EventCallback handler) Figure
inherited
onTouchCancel(EventCallback handler) Figure
inherited
onTouchEnd(EventCallback handler) Figure
inherited
onTouchMove(EventCallback handler) Figure
inherited
onTouchStart(EventCallback handler) Figure
inherited
onTransitionEnd(EventCallback handler) Figure
inherited
onVolumeChange(EventCallback handler) Figure
inherited
onWheel(EventCallback handler) Figure
inherited
style(Map<String, String> style) Figure
inherited
tabIndex(int value) Figure
Sets the tab order index for keyboard navigation.
inherited
title(String value) Figure
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited