Footer class final

Inheritance

Constructors

Footer({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Footer
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Footer
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Footer
Hides the element from screen readers.
inherited
ariaLabel(String value) Footer
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Footer
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Footer
inherited
data(String key, String value) Footer
Sets a custom data attribute.
inherited
hidden([bool h = true]) Footer
Hides the element from display.
inherited
id(String id) Footer
Sets the element's unique identifier.
inherited
lang(String value) Footer
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Footer
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Footer
inherited
onAnimationIteration(EventCallback handler) Footer
inherited
onAnimationStart(EventCallback handler) Footer
inherited
onBlur(EventCallback handler) Footer
inherited
onCanPlay(EventCallback handler) Footer
inherited
onCanPlayThrough(EventCallback handler) Footer
inherited
onChange(EventCallback handler) Footer
inherited
onClick(EventCallback handler) Footer
inherited
onContextMenu(EventCallback handler) Footer
inherited
onCopy(EventCallback handler) Footer
inherited
onCut(EventCallback handler) Footer
inherited
onDoubleClick(EventCallback handler) Footer
inherited
onDrag(EventCallback handler) Footer
inherited
onDragEnd(EventCallback handler) Footer
inherited
onDragEnter(EventCallback handler) Footer
inherited
onDragLeave(EventCallback handler) Footer
inherited
onDragOver(EventCallback handler) Footer
inherited
onDragStart(EventCallback handler) Footer
inherited
onDrop(EventCallback handler) Footer
inherited
onEnded(EventCallback handler) Footer
inherited
onFocus(EventCallback handler) Footer
inherited
onFocusIn(EventCallback handler) Footer
inherited
onFocusOut(EventCallback handler) Footer
inherited
onInput(EventCallback handler) Footer
inherited
onKeyDown(EventCallback handler) Footer
inherited
onKeyPress(EventCallback handler) Footer
inherited
onKeyUp(EventCallback handler) Footer
inherited
onLoadedData(EventCallback handler) Footer
inherited
onLoadedMetadata(EventCallback handler) Footer
inherited
onMouseDown(EventCallback handler) Footer
inherited
onMouseEnter(EventCallback handler) Footer
inherited
onMouseLeave(EventCallback handler) Footer
inherited
onMouseMove(EventCallback handler) Footer
inherited
onMouseOut(EventCallback handler) Footer
inherited
onMouseOver(EventCallback handler) Footer
inherited
onMouseUp(EventCallback handler) Footer
inherited
onPaste(EventCallback handler) Footer
inherited
onPause(EventCallback handler) Footer
inherited
onPlay(EventCallback handler) Footer
inherited
onPointerCancel(EventCallback handler) Footer
inherited
onPointerDown(EventCallback handler) Footer
inherited
onPointerEnter(EventCallback handler) Footer
inherited
onPointerLeave(EventCallback handler) Footer
inherited
onPointerMove(EventCallback handler) Footer
inherited
onPointerUp(EventCallback handler) Footer
inherited
onReset(EventCallback handler) Footer
inherited
onScroll(EventCallback handler) Footer
inherited
onSelect(EventCallback handler) Footer
inherited
onSubmit(EventCallback handler) Footer
inherited
onTimeUpdate(EventCallback handler) Footer
inherited
onTouchCancel(EventCallback handler) Footer
inherited
onTouchEnd(EventCallback handler) Footer
inherited
onTouchMove(EventCallback handler) Footer
inherited
onTouchStart(EventCallback handler) Footer
inherited
onTransitionEnd(EventCallback handler) Footer
inherited
onVolumeChange(EventCallback handler) Footer
inherited
onWheel(EventCallback handler) Footer
inherited
style(Map<String, String> style) Footer
inherited
tabIndex(int value) Footer
Sets the tab order index for keyboard navigation.
inherited
title(String value) Footer
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited