Hgroup class final

Inheritance

Constructors

Hgroup({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Hgroup
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Hgroup
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Hgroup
Hides the element from screen readers.
inherited
ariaLabel(String value) Hgroup
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Hgroup
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Hgroup
inherited
data(String key, String value) Hgroup
Sets a custom data attribute.
inherited
hidden([bool h = true]) Hgroup
Hides the element from display.
inherited
id(String id) Hgroup
Sets the element's unique identifier.
inherited
lang(String value) Hgroup
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Hgroup
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Hgroup
inherited
onAnimationIteration(EventCallback handler) Hgroup
inherited
onAnimationStart(EventCallback handler) Hgroup
inherited
onBlur(EventCallback handler) Hgroup
inherited
onCanPlay(EventCallback handler) Hgroup
inherited
onCanPlayThrough(EventCallback handler) Hgroup
inherited
onChange(EventCallback handler) Hgroup
inherited
onClick(EventCallback handler) Hgroup
inherited
onContextMenu(EventCallback handler) Hgroup
inherited
onCopy(EventCallback handler) Hgroup
inherited
onCut(EventCallback handler) Hgroup
inherited
onDoubleClick(EventCallback handler) Hgroup
inherited
onDrag(EventCallback handler) Hgroup
inherited
onDragEnd(EventCallback handler) Hgroup
inherited
onDragEnter(EventCallback handler) Hgroup
inherited
onDragLeave(EventCallback handler) Hgroup
inherited
onDragOver(EventCallback handler) Hgroup
inherited
onDragStart(EventCallback handler) Hgroup
inherited
onDrop(EventCallback handler) Hgroup
inherited
onEnded(EventCallback handler) Hgroup
inherited
onFocus(EventCallback handler) Hgroup
inherited
onFocusIn(EventCallback handler) Hgroup
inherited
onFocusOut(EventCallback handler) Hgroup
inherited
onInput(EventCallback handler) Hgroup
inherited
onKeyDown(EventCallback handler) Hgroup
inherited
onKeyPress(EventCallback handler) Hgroup
inherited
onKeyUp(EventCallback handler) Hgroup
inherited
onLoadedData(EventCallback handler) Hgroup
inherited
onLoadedMetadata(EventCallback handler) Hgroup
inherited
onMouseDown(EventCallback handler) Hgroup
inherited
onMouseEnter(EventCallback handler) Hgroup
inherited
onMouseLeave(EventCallback handler) Hgroup
inherited
onMouseMove(EventCallback handler) Hgroup
inherited
onMouseOut(EventCallback handler) Hgroup
inherited
onMouseOver(EventCallback handler) Hgroup
inherited
onMouseUp(EventCallback handler) Hgroup
inherited
onPaste(EventCallback handler) Hgroup
inherited
onPause(EventCallback handler) Hgroup
inherited
onPlay(EventCallback handler) Hgroup
inherited
onPointerCancel(EventCallback handler) Hgroup
inherited
onPointerDown(EventCallback handler) Hgroup
inherited
onPointerEnter(EventCallback handler) Hgroup
inherited
onPointerLeave(EventCallback handler) Hgroup
inherited
onPointerMove(EventCallback handler) Hgroup
inherited
onPointerUp(EventCallback handler) Hgroup
inherited
onReset(EventCallback handler) Hgroup
inherited
onScroll(EventCallback handler) Hgroup
inherited
onSelect(EventCallback handler) Hgroup
inherited
onSubmit(EventCallback handler) Hgroup
inherited
onTimeUpdate(EventCallback handler) Hgroup
inherited
onTouchCancel(EventCallback handler) Hgroup
inherited
onTouchEnd(EventCallback handler) Hgroup
inherited
onTouchMove(EventCallback handler) Hgroup
inherited
onTouchStart(EventCallback handler) Hgroup
inherited
onTransitionEnd(EventCallback handler) Hgroup
inherited
onVolumeChange(EventCallback handler) Hgroup
inherited
onWheel(EventCallback handler) Hgroup
inherited
style(Map<String, String> style) Hgroup
inherited
tabIndex(int value) Hgroup
Sets the tab order index for keyboard navigation.
inherited
title(String value) Hgroup
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited