Iframe class final

Inheritance

Constructors

Iframe({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Iframe
no setterinherited
tag String
finalinherited

Methods

allow(String a) Iframe
ariaDescribedBy(String id) Iframe
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Iframe
Hides the element from screen readers.
inherited
ariaLabel(String value) Iframe
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Iframe
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Iframe
inherited
data(String key, String value) Iframe
Sets a custom data attribute.
inherited
height(int h) Iframe
hidden([bool h = true]) Iframe
Hides the element from display.
inherited
id(String id) Iframe
Sets the element's unique identifier.
inherited
lang(String value) Iframe
Sets the language of the element's content.
inherited
loading(String l) Iframe
name(String n) Iframe
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Iframe
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Iframe
inherited
onAnimationIteration(EventCallback handler) Iframe
inherited
onAnimationStart(EventCallback handler) Iframe
inherited
onBlur(EventCallback handler) Iframe
inherited
onCanPlay(EventCallback handler) Iframe
inherited
onCanPlayThrough(EventCallback handler) Iframe
inherited
onChange(EventCallback handler) Iframe
inherited
onClick(EventCallback handler) Iframe
inherited
onContextMenu(EventCallback handler) Iframe
inherited
onCopy(EventCallback handler) Iframe
inherited
onCut(EventCallback handler) Iframe
inherited
onDoubleClick(EventCallback handler) Iframe
inherited
onDrag(EventCallback handler) Iframe
inherited
onDragEnd(EventCallback handler) Iframe
inherited
onDragEnter(EventCallback handler) Iframe
inherited
onDragLeave(EventCallback handler) Iframe
inherited
onDragOver(EventCallback handler) Iframe
inherited
onDragStart(EventCallback handler) Iframe
inherited
onDrop(EventCallback handler) Iframe
inherited
onEnded(EventCallback handler) Iframe
inherited
onFocus(EventCallback handler) Iframe
inherited
onFocusIn(EventCallback handler) Iframe
inherited
onFocusOut(EventCallback handler) Iframe
inherited
onInput(EventCallback handler) Iframe
inherited
onKeyDown(EventCallback handler) Iframe
inherited
onKeyPress(EventCallback handler) Iframe
inherited
onKeyUp(EventCallback handler) Iframe
inherited
onLoadedData(EventCallback handler) Iframe
inherited
onLoadedMetadata(EventCallback handler) Iframe
inherited
onMouseDown(EventCallback handler) Iframe
inherited
onMouseEnter(EventCallback handler) Iframe
inherited
onMouseLeave(EventCallback handler) Iframe
inherited
onMouseMove(EventCallback handler) Iframe
inherited
onMouseOut(EventCallback handler) Iframe
inherited
onMouseOver(EventCallback handler) Iframe
inherited
onMouseUp(EventCallback handler) Iframe
inherited
onPaste(EventCallback handler) Iframe
inherited
onPause(EventCallback handler) Iframe
inherited
onPlay(EventCallback handler) Iframe
inherited
onPointerCancel(EventCallback handler) Iframe
inherited
onPointerDown(EventCallback handler) Iframe
inherited
onPointerEnter(EventCallback handler) Iframe
inherited
onPointerLeave(EventCallback handler) Iframe
inherited
onPointerMove(EventCallback handler) Iframe
inherited
onPointerUp(EventCallback handler) Iframe
inherited
onReset(EventCallback handler) Iframe
inherited
onScroll(EventCallback handler) Iframe
inherited
onSelect(EventCallback handler) Iframe
inherited
onSubmit(EventCallback handler) Iframe
inherited
onTimeUpdate(EventCallback handler) Iframe
inherited
onTouchCancel(EventCallback handler) Iframe
inherited
onTouchEnd(EventCallback handler) Iframe
inherited
onTouchMove(EventCallback handler) Iframe
inherited
onTouchStart(EventCallback handler) Iframe
inherited
onTransitionEnd(EventCallback handler) Iframe
inherited
onVolumeChange(EventCallback handler) Iframe
inherited
onWheel(EventCallback handler) Iframe
inherited
referrerpolicy(String rp) Iframe
sandbox(String s) Iframe
src(String s) Iframe
srcdoc(String sd) Iframe
style(Map<String, String> style) Iframe
inherited
tabIndex(int value) Iframe
Sets the tab order index for keyboard navigation.
inherited
title(String value) Iframe
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
width(int w) Iframe

Operators

operator ==(Object other) bool
The equality operator.
inherited