Ins class final

Inheritance

Constructors

Ins({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Ins
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Ins
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Ins
Hides the element from screen readers.
inherited
ariaLabel(String value) Ins
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Ins
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
cite(String c) Ins
classes(String classes) Ins
inherited
data(String key, String value) Ins
Sets a custom data attribute.
inherited
datetime(String dt) Ins
hidden([bool h = true]) Ins
Hides the element from display.
inherited
id(String id) Ins
Sets the element's unique identifier.
inherited
lang(String value) Ins
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Ins
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Ins
inherited
onAnimationIteration(EventCallback handler) Ins
inherited
onAnimationStart(EventCallback handler) Ins
inherited
onBlur(EventCallback handler) Ins
inherited
onCanPlay(EventCallback handler) Ins
inherited
onCanPlayThrough(EventCallback handler) Ins
inherited
onChange(EventCallback handler) Ins
inherited
onClick(EventCallback handler) Ins
inherited
onContextMenu(EventCallback handler) Ins
inherited
onCopy(EventCallback handler) Ins
inherited
onCut(EventCallback handler) Ins
inherited
onDoubleClick(EventCallback handler) Ins
inherited
onDrag(EventCallback handler) Ins
inherited
onDragEnd(EventCallback handler) Ins
inherited
onDragEnter(EventCallback handler) Ins
inherited
onDragLeave(EventCallback handler) Ins
inherited
onDragOver(EventCallback handler) Ins
inherited
onDragStart(EventCallback handler) Ins
inherited
onDrop(EventCallback handler) Ins
inherited
onEnded(EventCallback handler) Ins
inherited
onFocus(EventCallback handler) Ins
inherited
onFocusIn(EventCallback handler) Ins
inherited
onFocusOut(EventCallback handler) Ins
inherited
onInput(EventCallback handler) Ins
inherited
onKeyDown(EventCallback handler) Ins
inherited
onKeyPress(EventCallback handler) Ins
inherited
onKeyUp(EventCallback handler) Ins
inherited
onLoadedData(EventCallback handler) Ins
inherited
onLoadedMetadata(EventCallback handler) Ins
inherited
onMouseDown(EventCallback handler) Ins
inherited
onMouseEnter(EventCallback handler) Ins
inherited
onMouseLeave(EventCallback handler) Ins
inherited
onMouseMove(EventCallback handler) Ins
inherited
onMouseOut(EventCallback handler) Ins
inherited
onMouseOver(EventCallback handler) Ins
inherited
onMouseUp(EventCallback handler) Ins
inherited
onPaste(EventCallback handler) Ins
inherited
onPause(EventCallback handler) Ins
inherited
onPlay(EventCallback handler) Ins
inherited
onPointerCancel(EventCallback handler) Ins
inherited
onPointerDown(EventCallback handler) Ins
inherited
onPointerEnter(EventCallback handler) Ins
inherited
onPointerLeave(EventCallback handler) Ins
inherited
onPointerMove(EventCallback handler) Ins
inherited
onPointerUp(EventCallback handler) Ins
inherited
onReset(EventCallback handler) Ins
inherited
onScroll(EventCallback handler) Ins
inherited
onSelect(EventCallback handler) Ins
inherited
onSubmit(EventCallback handler) Ins
inherited
onTimeUpdate(EventCallback handler) Ins
inherited
onTouchCancel(EventCallback handler) Ins
inherited
onTouchEnd(EventCallback handler) Ins
inherited
onTouchMove(EventCallback handler) Ins
inherited
onTouchStart(EventCallback handler) Ins
inherited
onTransitionEnd(EventCallback handler) Ins
inherited
onVolumeChange(EventCallback handler) Ins
inherited
onWheel(EventCallback handler) Ins
inherited
style(Map<String, String> style) Ins
inherited
tabIndex(int value) Ins
Sets the tab order index for keyboard navigation.
inherited
title(String value) Ins
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited