Kbd class final

Inheritance

Constructors

Kbd({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Kbd
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Kbd
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Kbd
Hides the element from screen readers.
inherited
ariaLabel(String value) Kbd
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Kbd
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Kbd
inherited
data(String key, String value) Kbd
Sets a custom data attribute.
inherited
hidden([bool h = true]) Kbd
Hides the element from display.
inherited
id(String id) Kbd
Sets the element's unique identifier.
inherited
lang(String value) Kbd
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Kbd
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Kbd
inherited
onAnimationIteration(EventCallback handler) Kbd
inherited
onAnimationStart(EventCallback handler) Kbd
inherited
onBlur(EventCallback handler) Kbd
inherited
onCanPlay(EventCallback handler) Kbd
inherited
onCanPlayThrough(EventCallback handler) Kbd
inherited
onChange(EventCallback handler) Kbd
inherited
onClick(EventCallback handler) Kbd
inherited
onContextMenu(EventCallback handler) Kbd
inherited
onCopy(EventCallback handler) Kbd
inherited
onCut(EventCallback handler) Kbd
inherited
onDoubleClick(EventCallback handler) Kbd
inherited
onDrag(EventCallback handler) Kbd
inherited
onDragEnd(EventCallback handler) Kbd
inherited
onDragEnter(EventCallback handler) Kbd
inherited
onDragLeave(EventCallback handler) Kbd
inherited
onDragOver(EventCallback handler) Kbd
inherited
onDragStart(EventCallback handler) Kbd
inherited
onDrop(EventCallback handler) Kbd
inherited
onEnded(EventCallback handler) Kbd
inherited
onFocus(EventCallback handler) Kbd
inherited
onFocusIn(EventCallback handler) Kbd
inherited
onFocusOut(EventCallback handler) Kbd
inherited
onInput(EventCallback handler) Kbd
inherited
onKeyDown(EventCallback handler) Kbd
inherited
onKeyPress(EventCallback handler) Kbd
inherited
onKeyUp(EventCallback handler) Kbd
inherited
onLoadedData(EventCallback handler) Kbd
inherited
onLoadedMetadata(EventCallback handler) Kbd
inherited
onMouseDown(EventCallback handler) Kbd
inherited
onMouseEnter(EventCallback handler) Kbd
inherited
onMouseLeave(EventCallback handler) Kbd
inherited
onMouseMove(EventCallback handler) Kbd
inherited
onMouseOut(EventCallback handler) Kbd
inherited
onMouseOver(EventCallback handler) Kbd
inherited
onMouseUp(EventCallback handler) Kbd
inherited
onPaste(EventCallback handler) Kbd
inherited
onPause(EventCallback handler) Kbd
inherited
onPlay(EventCallback handler) Kbd
inherited
onPointerCancel(EventCallback handler) Kbd
inherited
onPointerDown(EventCallback handler) Kbd
inherited
onPointerEnter(EventCallback handler) Kbd
inherited
onPointerLeave(EventCallback handler) Kbd
inherited
onPointerMove(EventCallback handler) Kbd
inherited
onPointerUp(EventCallback handler) Kbd
inherited
onReset(EventCallback handler) Kbd
inherited
onScroll(EventCallback handler) Kbd
inherited
onSelect(EventCallback handler) Kbd
inherited
onSubmit(EventCallback handler) Kbd
inherited
onTimeUpdate(EventCallback handler) Kbd
inherited
onTouchCancel(EventCallback handler) Kbd
inherited
onTouchEnd(EventCallback handler) Kbd
inherited
onTouchMove(EventCallback handler) Kbd
inherited
onTouchStart(EventCallback handler) Kbd
inherited
onTransitionEnd(EventCallback handler) Kbd
inherited
onVolumeChange(EventCallback handler) Kbd
inherited
onWheel(EventCallback handler) Kbd
inherited
style(Map<String, String> style) Kbd
inherited
tabIndex(int value) Kbd
Sets the tab order index for keyboard navigation.
inherited
title(String value) Kbd
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited