Main class final

Inheritance

Constructors

Main({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Main
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Main
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Main
Hides the element from screen readers.
inherited
ariaLabel(String value) Main
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Main
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Main
inherited
data(String key, String value) Main
Sets a custom data attribute.
inherited
hidden([bool h = true]) Main
Hides the element from display.
inherited
id(String id) Main
Sets the element's unique identifier.
inherited
lang(String value) Main
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Main
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Main
inherited
onAnimationIteration(EventCallback handler) Main
inherited
onAnimationStart(EventCallback handler) Main
inherited
onBlur(EventCallback handler) Main
inherited
onCanPlay(EventCallback handler) Main
inherited
onCanPlayThrough(EventCallback handler) Main
inherited
onChange(EventCallback handler) Main
inherited
onClick(EventCallback handler) Main
inherited
onContextMenu(EventCallback handler) Main
inherited
onCopy(EventCallback handler) Main
inherited
onCut(EventCallback handler) Main
inherited
onDoubleClick(EventCallback handler) Main
inherited
onDrag(EventCallback handler) Main
inherited
onDragEnd(EventCallback handler) Main
inherited
onDragEnter(EventCallback handler) Main
inherited
onDragLeave(EventCallback handler) Main
inherited
onDragOver(EventCallback handler) Main
inherited
onDragStart(EventCallback handler) Main
inherited
onDrop(EventCallback handler) Main
inherited
onEnded(EventCallback handler) Main
inherited
onFocus(EventCallback handler) Main
inherited
onFocusIn(EventCallback handler) Main
inherited
onFocusOut(EventCallback handler) Main
inherited
onInput(EventCallback handler) Main
inherited
onKeyDown(EventCallback handler) Main
inherited
onKeyPress(EventCallback handler) Main
inherited
onKeyUp(EventCallback handler) Main
inherited
onLoadedData(EventCallback handler) Main
inherited
onLoadedMetadata(EventCallback handler) Main
inherited
onMouseDown(EventCallback handler) Main
inherited
onMouseEnter(EventCallback handler) Main
inherited
onMouseLeave(EventCallback handler) Main
inherited
onMouseMove(EventCallback handler) Main
inherited
onMouseOut(EventCallback handler) Main
inherited
onMouseOver(EventCallback handler) Main
inherited
onMouseUp(EventCallback handler) Main
inherited
onPaste(EventCallback handler) Main
inherited
onPause(EventCallback handler) Main
inherited
onPlay(EventCallback handler) Main
inherited
onPointerCancel(EventCallback handler) Main
inherited
onPointerDown(EventCallback handler) Main
inherited
onPointerEnter(EventCallback handler) Main
inherited
onPointerLeave(EventCallback handler) Main
inherited
onPointerMove(EventCallback handler) Main
inherited
onPointerUp(EventCallback handler) Main
inherited
onReset(EventCallback handler) Main
inherited
onScroll(EventCallback handler) Main
inherited
onSelect(EventCallback handler) Main
inherited
onSubmit(EventCallback handler) Main
inherited
onTimeUpdate(EventCallback handler) Main
inherited
onTouchCancel(EventCallback handler) Main
inherited
onTouchEnd(EventCallback handler) Main
inherited
onTouchMove(EventCallback handler) Main
inherited
onTouchStart(EventCallback handler) Main
inherited
onTransitionEnd(EventCallback handler) Main
inherited
onVolumeChange(EventCallback handler) Main
inherited
onWheel(EventCallback handler) Main
inherited
style(Map<String, String> style) Main
inherited
tabIndex(int value) Main
Sets the tab order index for keyboard navigation.
inherited
title(String value) Main
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited