Mark class final

Inheritance

Constructors

Mark({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Mark
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Mark
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Mark
Hides the element from screen readers.
inherited
ariaLabel(String value) Mark
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Mark
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Mark
inherited
data(String key, String value) Mark
Sets a custom data attribute.
inherited
hidden([bool h = true]) Mark
Hides the element from display.
inherited
id(String id) Mark
Sets the element's unique identifier.
inherited
lang(String value) Mark
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Mark
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Mark
inherited
onAnimationIteration(EventCallback handler) Mark
inherited
onAnimationStart(EventCallback handler) Mark
inherited
onBlur(EventCallback handler) Mark
inherited
onCanPlay(EventCallback handler) Mark
inherited
onCanPlayThrough(EventCallback handler) Mark
inherited
onChange(EventCallback handler) Mark
inherited
onClick(EventCallback handler) Mark
inherited
onContextMenu(EventCallback handler) Mark
inherited
onCopy(EventCallback handler) Mark
inherited
onCut(EventCallback handler) Mark
inherited
onDoubleClick(EventCallback handler) Mark
inherited
onDrag(EventCallback handler) Mark
inherited
onDragEnd(EventCallback handler) Mark
inherited
onDragEnter(EventCallback handler) Mark
inherited
onDragLeave(EventCallback handler) Mark
inherited
onDragOver(EventCallback handler) Mark
inherited
onDragStart(EventCallback handler) Mark
inherited
onDrop(EventCallback handler) Mark
inherited
onEnded(EventCallback handler) Mark
inherited
onFocus(EventCallback handler) Mark
inherited
onFocusIn(EventCallback handler) Mark
inherited
onFocusOut(EventCallback handler) Mark
inherited
onInput(EventCallback handler) Mark
inherited
onKeyDown(EventCallback handler) Mark
inherited
onKeyPress(EventCallback handler) Mark
inherited
onKeyUp(EventCallback handler) Mark
inherited
onLoadedData(EventCallback handler) Mark
inherited
onLoadedMetadata(EventCallback handler) Mark
inherited
onMouseDown(EventCallback handler) Mark
inherited
onMouseEnter(EventCallback handler) Mark
inherited
onMouseLeave(EventCallback handler) Mark
inherited
onMouseMove(EventCallback handler) Mark
inherited
onMouseOut(EventCallback handler) Mark
inherited
onMouseOver(EventCallback handler) Mark
inherited
onMouseUp(EventCallback handler) Mark
inherited
onPaste(EventCallback handler) Mark
inherited
onPause(EventCallback handler) Mark
inherited
onPlay(EventCallback handler) Mark
inherited
onPointerCancel(EventCallback handler) Mark
inherited
onPointerDown(EventCallback handler) Mark
inherited
onPointerEnter(EventCallback handler) Mark
inherited
onPointerLeave(EventCallback handler) Mark
inherited
onPointerMove(EventCallback handler) Mark
inherited
onPointerUp(EventCallback handler) Mark
inherited
onReset(EventCallback handler) Mark
inherited
onScroll(EventCallback handler) Mark
inherited
onSelect(EventCallback handler) Mark
inherited
onSubmit(EventCallback handler) Mark
inherited
onTimeUpdate(EventCallback handler) Mark
inherited
onTouchCancel(EventCallback handler) Mark
inherited
onTouchEnd(EventCallback handler) Mark
inherited
onTouchMove(EventCallback handler) Mark
inherited
onTouchStart(EventCallback handler) Mark
inherited
onTransitionEnd(EventCallback handler) Mark
inherited
onVolumeChange(EventCallback handler) Mark
inherited
onWheel(EventCallback handler) Mark
inherited
style(Map<String, String> style) Mark
inherited
tabIndex(int value) Mark
Sets the tab order index for keyboard navigation.
inherited
title(String value) Mark
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited