Math class final

Inheritance

Constructors

Math({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Math
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Math
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Math
Hides the element from screen readers.
inherited
ariaLabel(String value) Math
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Math
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Math
inherited
data(String key, String value) Math
Sets a custom data attribute.
inherited
hidden([bool h = true]) Math
Hides the element from display.
inherited
id(String id) Math
Sets the element's unique identifier.
inherited
lang(String value) Math
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Math
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Math
inherited
onAnimationIteration(EventCallback handler) Math
inherited
onAnimationStart(EventCallback handler) Math
inherited
onBlur(EventCallback handler) Math
inherited
onCanPlay(EventCallback handler) Math
inherited
onCanPlayThrough(EventCallback handler) Math
inherited
onChange(EventCallback handler) Math
inherited
onClick(EventCallback handler) Math
inherited
onContextMenu(EventCallback handler) Math
inherited
onCopy(EventCallback handler) Math
inherited
onCut(EventCallback handler) Math
inherited
onDoubleClick(EventCallback handler) Math
inherited
onDrag(EventCallback handler) Math
inherited
onDragEnd(EventCallback handler) Math
inherited
onDragEnter(EventCallback handler) Math
inherited
onDragLeave(EventCallback handler) Math
inherited
onDragOver(EventCallback handler) Math
inherited
onDragStart(EventCallback handler) Math
inherited
onDrop(EventCallback handler) Math
inherited
onEnded(EventCallback handler) Math
inherited
onFocus(EventCallback handler) Math
inherited
onFocusIn(EventCallback handler) Math
inherited
onFocusOut(EventCallback handler) Math
inherited
onInput(EventCallback handler) Math
inherited
onKeyDown(EventCallback handler) Math
inherited
onKeyPress(EventCallback handler) Math
inherited
onKeyUp(EventCallback handler) Math
inherited
onLoadedData(EventCallback handler) Math
inherited
onLoadedMetadata(EventCallback handler) Math
inherited
onMouseDown(EventCallback handler) Math
inherited
onMouseEnter(EventCallback handler) Math
inherited
onMouseLeave(EventCallback handler) Math
inherited
onMouseMove(EventCallback handler) Math
inherited
onMouseOut(EventCallback handler) Math
inherited
onMouseOver(EventCallback handler) Math
inherited
onMouseUp(EventCallback handler) Math
inherited
onPaste(EventCallback handler) Math
inherited
onPause(EventCallback handler) Math
inherited
onPlay(EventCallback handler) Math
inherited
onPointerCancel(EventCallback handler) Math
inherited
onPointerDown(EventCallback handler) Math
inherited
onPointerEnter(EventCallback handler) Math
inherited
onPointerLeave(EventCallback handler) Math
inherited
onPointerMove(EventCallback handler) Math
inherited
onPointerUp(EventCallback handler) Math
inherited
onReset(EventCallback handler) Math
inherited
onScroll(EventCallback handler) Math
inherited
onSelect(EventCallback handler) Math
inherited
onSubmit(EventCallback handler) Math
inherited
onTimeUpdate(EventCallback handler) Math
inherited
onTouchCancel(EventCallback handler) Math
inherited
onTouchEnd(EventCallback handler) Math
inherited
onTouchMove(EventCallback handler) Math
inherited
onTouchStart(EventCallback handler) Math
inherited
onTransitionEnd(EventCallback handler) Math
inherited
onVolumeChange(EventCallback handler) Math
inherited
onWheel(EventCallback handler) Math
inherited
style(Map<String, String> style) Math
inherited
tabIndex(int value) Math
Sets the tab order index for keyboard navigation.
inherited
title(String value) Math
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
xmlns(String ns) Math

Operators

operator ==(Object other) bool
The equality operator.
inherited