Nav class final

Inheritance

Constructors

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Nav
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Nav
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Nav
Hides the element from screen readers.
inherited
ariaLabel(String value) Nav
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Nav
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Nav
inherited
data(String key, String value) Nav
Sets a custom data attribute.
inherited
hidden([bool h = true]) Nav
Hides the element from display.
inherited
id(String id) Nav
Sets the element's unique identifier.
inherited
lang(String value) Nav
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Nav
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Nav
inherited
onAnimationIteration(EventCallback handler) Nav
inherited
onAnimationStart(EventCallback handler) Nav
inherited
onBlur(EventCallback handler) Nav
inherited
onCanPlay(EventCallback handler) Nav
inherited
onCanPlayThrough(EventCallback handler) Nav
inherited
onChange(EventCallback handler) Nav
inherited
onClick(EventCallback handler) Nav
inherited
onContextMenu(EventCallback handler) Nav
inherited
onCopy(EventCallback handler) Nav
inherited
onCut(EventCallback handler) Nav
inherited
onDoubleClick(EventCallback handler) Nav
inherited
onDrag(EventCallback handler) Nav
inherited
onDragEnd(EventCallback handler) Nav
inherited
onDragEnter(EventCallback handler) Nav
inherited
onDragLeave(EventCallback handler) Nav
inherited
onDragOver(EventCallback handler) Nav
inherited
onDragStart(EventCallback handler) Nav
inherited
onDrop(EventCallback handler) Nav
inherited
onEnded(EventCallback handler) Nav
inherited
onFocus(EventCallback handler) Nav
inherited
onFocusIn(EventCallback handler) Nav
inherited
onFocusOut(EventCallback handler) Nav
inherited
onInput(EventCallback handler) Nav
inherited
onKeyDown(EventCallback handler) Nav
inherited
onKeyPress(EventCallback handler) Nav
inherited
onKeyUp(EventCallback handler) Nav
inherited
onLoadedData(EventCallback handler) Nav
inherited
onLoadedMetadata(EventCallback handler) Nav
inherited
onMouseDown(EventCallback handler) Nav
inherited
onMouseEnter(EventCallback handler) Nav
inherited
onMouseLeave(EventCallback handler) Nav
inherited
onMouseMove(EventCallback handler) Nav
inherited
onMouseOut(EventCallback handler) Nav
inherited
onMouseOver(EventCallback handler) Nav
inherited
onMouseUp(EventCallback handler) Nav
inherited
onPaste(EventCallback handler) Nav
inherited
onPause(EventCallback handler) Nav
inherited
onPlay(EventCallback handler) Nav
inherited
onPointerCancel(EventCallback handler) Nav
inherited
onPointerDown(EventCallback handler) Nav
inherited
onPointerEnter(EventCallback handler) Nav
inherited
onPointerLeave(EventCallback handler) Nav
inherited
onPointerMove(EventCallback handler) Nav
inherited
onPointerUp(EventCallback handler) Nav
inherited
onReset(EventCallback handler) Nav
inherited
onScroll(EventCallback handler) Nav
inherited
onSelect(EventCallback handler) Nav
inherited
onSubmit(EventCallback handler) Nav
inherited
onTimeUpdate(EventCallback handler) Nav
inherited
onTouchCancel(EventCallback handler) Nav
inherited
onTouchEnd(EventCallback handler) Nav
inherited
onTouchMove(EventCallback handler) Nav
inherited
onTouchStart(EventCallback handler) Nav
inherited
onTransitionEnd(EventCallback handler) Nav
inherited
onVolumeChange(EventCallback handler) Nav
inherited
onWheel(EventCallback handler) Nav
inherited
style(Map<String, String> style) Nav
inherited
tabIndex(int value) Nav
Sets the tab order index for keyboard navigation.
inherited
title(String value) Nav
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited