Option class final

Inheritance

Constructors

Option({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Option
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Option
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Option
Hides the element from screen readers.
inherited
ariaLabel(String value) Option
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Option
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Option
inherited
data(String key, String value) Option
Sets a custom data attribute.
inherited
disabled([bool d = true]) Option
hidden([bool h = true]) Option
Hides the element from display.
inherited
id(String id) Option
Sets the element's unique identifier.
inherited
label(String l) Option
lang(String value) Option
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Option
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Option
inherited
onAnimationIteration(EventCallback handler) Option
inherited
onAnimationStart(EventCallback handler) Option
inherited
onBlur(EventCallback handler) Option
inherited
onCanPlay(EventCallback handler) Option
inherited
onCanPlayThrough(EventCallback handler) Option
inherited
onChange(EventCallback handler) Option
inherited
onClick(EventCallback handler) Option
inherited
onContextMenu(EventCallback handler) Option
inherited
onCopy(EventCallback handler) Option
inherited
onCut(EventCallback handler) Option
inherited
onDoubleClick(EventCallback handler) Option
inherited
onDrag(EventCallback handler) Option
inherited
onDragEnd(EventCallback handler) Option
inherited
onDragEnter(EventCallback handler) Option
inherited
onDragLeave(EventCallback handler) Option
inherited
onDragOver(EventCallback handler) Option
inherited
onDragStart(EventCallback handler) Option
inherited
onDrop(EventCallback handler) Option
inherited
onEnded(EventCallback handler) Option
inherited
onFocus(EventCallback handler) Option
inherited
onFocusIn(EventCallback handler) Option
inherited
onFocusOut(EventCallback handler) Option
inherited
onInput(EventCallback handler) Option
inherited
onKeyDown(EventCallback handler) Option
inherited
onKeyPress(EventCallback handler) Option
inherited
onKeyUp(EventCallback handler) Option
inherited
onLoadedData(EventCallback handler) Option
inherited
onLoadedMetadata(EventCallback handler) Option
inherited
onMouseDown(EventCallback handler) Option
inherited
onMouseEnter(EventCallback handler) Option
inherited
onMouseLeave(EventCallback handler) Option
inherited
onMouseMove(EventCallback handler) Option
inherited
onMouseOut(EventCallback handler) Option
inherited
onMouseOver(EventCallback handler) Option
inherited
onMouseUp(EventCallback handler) Option
inherited
onPaste(EventCallback handler) Option
inherited
onPause(EventCallback handler) Option
inherited
onPlay(EventCallback handler) Option
inherited
onPointerCancel(EventCallback handler) Option
inherited
onPointerDown(EventCallback handler) Option
inherited
onPointerEnter(EventCallback handler) Option
inherited
onPointerLeave(EventCallback handler) Option
inherited
onPointerMove(EventCallback handler) Option
inherited
onPointerUp(EventCallback handler) Option
inherited
onReset(EventCallback handler) Option
inherited
onScroll(EventCallback handler) Option
inherited
onSelect(EventCallback handler) Option
inherited
onSubmit(EventCallback handler) Option
inherited
onTimeUpdate(EventCallback handler) Option
inherited
onTouchCancel(EventCallback handler) Option
inherited
onTouchEnd(EventCallback handler) Option
inherited
onTouchMove(EventCallback handler) Option
inherited
onTouchStart(EventCallback handler) Option
inherited
onTransitionEnd(EventCallback handler) Option
inherited
onVolumeChange(EventCallback handler) Option
inherited
onWheel(EventCallback handler) Option
inherited
selected([bool isSelected = true]) Option
style(Map<String, String> style) Option
inherited
tabIndex(int value) Option
Sets the tab order index for keyboard navigation.
inherited
title(String value) Option
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
value(String val) Option

Operators

operator ==(Object other) bool
The equality operator.
inherited