Picture class final

Inheritance

Constructors

Picture({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Picture
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Picture
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Picture
Hides the element from screen readers.
inherited
ariaLabel(String value) Picture
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Picture
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Picture
inherited
data(String key, String value) Picture
Sets a custom data attribute.
inherited
hidden([bool h = true]) Picture
Hides the element from display.
inherited
id(String id) Picture
Sets the element's unique identifier.
inherited
lang(String value) Picture
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Picture
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Picture
inherited
onAnimationIteration(EventCallback handler) Picture
inherited
onAnimationStart(EventCallback handler) Picture
inherited
onBlur(EventCallback handler) Picture
inherited
onCanPlay(EventCallback handler) Picture
inherited
onCanPlayThrough(EventCallback handler) Picture
inherited
onChange(EventCallback handler) Picture
inherited
onClick(EventCallback handler) Picture
inherited
onContextMenu(EventCallback handler) Picture
inherited
onCopy(EventCallback handler) Picture
inherited
onCut(EventCallback handler) Picture
inherited
onDoubleClick(EventCallback handler) Picture
inherited
onDrag(EventCallback handler) Picture
inherited
onDragEnd(EventCallback handler) Picture
inherited
onDragEnter(EventCallback handler) Picture
inherited
onDragLeave(EventCallback handler) Picture
inherited
onDragOver(EventCallback handler) Picture
inherited
onDragStart(EventCallback handler) Picture
inherited
onDrop(EventCallback handler) Picture
inherited
onEnded(EventCallback handler) Picture
inherited
onFocus(EventCallback handler) Picture
inherited
onFocusIn(EventCallback handler) Picture
inherited
onFocusOut(EventCallback handler) Picture
inherited
onInput(EventCallback handler) Picture
inherited
onKeyDown(EventCallback handler) Picture
inherited
onKeyPress(EventCallback handler) Picture
inherited
onKeyUp(EventCallback handler) Picture
inherited
onLoadedData(EventCallback handler) Picture
inherited
onLoadedMetadata(EventCallback handler) Picture
inherited
onMouseDown(EventCallback handler) Picture
inherited
onMouseEnter(EventCallback handler) Picture
inherited
onMouseLeave(EventCallback handler) Picture
inherited
onMouseMove(EventCallback handler) Picture
inherited
onMouseOut(EventCallback handler) Picture
inherited
onMouseOver(EventCallback handler) Picture
inherited
onMouseUp(EventCallback handler) Picture
inherited
onPaste(EventCallback handler) Picture
inherited
onPause(EventCallback handler) Picture
inherited
onPlay(EventCallback handler) Picture
inherited
onPointerCancel(EventCallback handler) Picture
inherited
onPointerDown(EventCallback handler) Picture
inherited
onPointerEnter(EventCallback handler) Picture
inherited
onPointerLeave(EventCallback handler) Picture
inherited
onPointerMove(EventCallback handler) Picture
inherited
onPointerUp(EventCallback handler) Picture
inherited
onReset(EventCallback handler) Picture
inherited
onScroll(EventCallback handler) Picture
inherited
onSelect(EventCallback handler) Picture
inherited
onSubmit(EventCallback handler) Picture
inherited
onTimeUpdate(EventCallback handler) Picture
inherited
onTouchCancel(EventCallback handler) Picture
inherited
onTouchEnd(EventCallback handler) Picture
inherited
onTouchMove(EventCallback handler) Picture
inherited
onTouchStart(EventCallback handler) Picture
inherited
onTransitionEnd(EventCallback handler) Picture
inherited
onVolumeChange(EventCallback handler) Picture
inherited
onWheel(EventCallback handler) Picture
inherited
style(Map<String, String> style) Picture
inherited
tabIndex(int value) Picture
Sets the tab order index for keyboard navigation.
inherited
title(String value) Picture
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited