Pre class final

Inheritance

Constructors

Pre({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Pre
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Pre
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Pre
Hides the element from screen readers.
inherited
ariaLabel(String value) Pre
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Pre
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Pre
inherited
data(String key, String value) Pre
Sets a custom data attribute.
inherited
hidden([bool h = true]) Pre
Hides the element from display.
inherited
id(String id) Pre
Sets the element's unique identifier.
inherited
lang(String value) Pre
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Pre
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Pre
inherited
onAnimationIteration(EventCallback handler) Pre
inherited
onAnimationStart(EventCallback handler) Pre
inherited
onBlur(EventCallback handler) Pre
inherited
onCanPlay(EventCallback handler) Pre
inherited
onCanPlayThrough(EventCallback handler) Pre
inherited
onChange(EventCallback handler) Pre
inherited
onClick(EventCallback handler) Pre
inherited
onContextMenu(EventCallback handler) Pre
inherited
onCopy(EventCallback handler) Pre
inherited
onCut(EventCallback handler) Pre
inherited
onDoubleClick(EventCallback handler) Pre
inherited
onDrag(EventCallback handler) Pre
inherited
onDragEnd(EventCallback handler) Pre
inherited
onDragEnter(EventCallback handler) Pre
inherited
onDragLeave(EventCallback handler) Pre
inherited
onDragOver(EventCallback handler) Pre
inherited
onDragStart(EventCallback handler) Pre
inherited
onDrop(EventCallback handler) Pre
inherited
onEnded(EventCallback handler) Pre
inherited
onFocus(EventCallback handler) Pre
inherited
onFocusIn(EventCallback handler) Pre
inherited
onFocusOut(EventCallback handler) Pre
inherited
onInput(EventCallback handler) Pre
inherited
onKeyDown(EventCallback handler) Pre
inherited
onKeyPress(EventCallback handler) Pre
inherited
onKeyUp(EventCallback handler) Pre
inherited
onLoadedData(EventCallback handler) Pre
inherited
onLoadedMetadata(EventCallback handler) Pre
inherited
onMouseDown(EventCallback handler) Pre
inherited
onMouseEnter(EventCallback handler) Pre
inherited
onMouseLeave(EventCallback handler) Pre
inherited
onMouseMove(EventCallback handler) Pre
inherited
onMouseOut(EventCallback handler) Pre
inherited
onMouseOver(EventCallback handler) Pre
inherited
onMouseUp(EventCallback handler) Pre
inherited
onPaste(EventCallback handler) Pre
inherited
onPause(EventCallback handler) Pre
inherited
onPlay(EventCallback handler) Pre
inherited
onPointerCancel(EventCallback handler) Pre
inherited
onPointerDown(EventCallback handler) Pre
inherited
onPointerEnter(EventCallback handler) Pre
inherited
onPointerLeave(EventCallback handler) Pre
inherited
onPointerMove(EventCallback handler) Pre
inherited
onPointerUp(EventCallback handler) Pre
inherited
onReset(EventCallback handler) Pre
inherited
onScroll(EventCallback handler) Pre
inherited
onSelect(EventCallback handler) Pre
inherited
onSubmit(EventCallback handler) Pre
inherited
onTimeUpdate(EventCallback handler) Pre
inherited
onTouchCancel(EventCallback handler) Pre
inherited
onTouchEnd(EventCallback handler) Pre
inherited
onTouchMove(EventCallback handler) Pre
inherited
onTouchStart(EventCallback handler) Pre
inherited
onTransitionEnd(EventCallback handler) Pre
inherited
onVolumeChange(EventCallback handler) Pre
inherited
onWheel(EventCallback handler) Pre
inherited
style(Map<String, String> style) Pre
inherited
tabIndex(int value) Pre
Sets the tab order index for keyboard navigation.
inherited
title(String value) Pre
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited