Progress class final

Inheritance

Constructors

Progress({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Progress
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Progress
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Progress
Hides the element from screen readers.
inherited
ariaLabel(String value) Progress
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Progress
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Progress
inherited
data(String key, String value) Progress
Sets a custom data attribute.
inherited
hidden([bool h = true]) Progress
Hides the element from display.
inherited
id(String id) Progress
Sets the element's unique identifier.
inherited
lang(String value) Progress
Sets the language of the element's content.
inherited
max(num m) Progress
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Progress
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Progress
inherited
onAnimationIteration(EventCallback handler) Progress
inherited
onAnimationStart(EventCallback handler) Progress
inherited
onBlur(EventCallback handler) Progress
inherited
onCanPlay(EventCallback handler) Progress
inherited
onCanPlayThrough(EventCallback handler) Progress
inherited
onChange(EventCallback handler) Progress
inherited
onClick(EventCallback handler) Progress
inherited
onContextMenu(EventCallback handler) Progress
inherited
onCopy(EventCallback handler) Progress
inherited
onCut(EventCallback handler) Progress
inherited
onDoubleClick(EventCallback handler) Progress
inherited
onDrag(EventCallback handler) Progress
inherited
onDragEnd(EventCallback handler) Progress
inherited
onDragEnter(EventCallback handler) Progress
inherited
onDragLeave(EventCallback handler) Progress
inherited
onDragOver(EventCallback handler) Progress
inherited
onDragStart(EventCallback handler) Progress
inherited
onDrop(EventCallback handler) Progress
inherited
onEnded(EventCallback handler) Progress
inherited
onFocus(EventCallback handler) Progress
inherited
onFocusIn(EventCallback handler) Progress
inherited
onFocusOut(EventCallback handler) Progress
inherited
onInput(EventCallback handler) Progress
inherited
onKeyDown(EventCallback handler) Progress
inherited
onKeyPress(EventCallback handler) Progress
inherited
onKeyUp(EventCallback handler) Progress
inherited
onLoadedData(EventCallback handler) Progress
inherited
onLoadedMetadata(EventCallback handler) Progress
inherited
onMouseDown(EventCallback handler) Progress
inherited
onMouseEnter(EventCallback handler) Progress
inherited
onMouseLeave(EventCallback handler) Progress
inherited
onMouseMove(EventCallback handler) Progress
inherited
onMouseOut(EventCallback handler) Progress
inherited
onMouseOver(EventCallback handler) Progress
inherited
onMouseUp(EventCallback handler) Progress
inherited
onPaste(EventCallback handler) Progress
inherited
onPause(EventCallback handler) Progress
inherited
onPlay(EventCallback handler) Progress
inherited
onPointerCancel(EventCallback handler) Progress
inherited
onPointerDown(EventCallback handler) Progress
inherited
onPointerEnter(EventCallback handler) Progress
inherited
onPointerLeave(EventCallback handler) Progress
inherited
onPointerMove(EventCallback handler) Progress
inherited
onPointerUp(EventCallback handler) Progress
inherited
onReset(EventCallback handler) Progress
inherited
onScroll(EventCallback handler) Progress
inherited
onSelect(EventCallback handler) Progress
inherited
onSubmit(EventCallback handler) Progress
inherited
onTimeUpdate(EventCallback handler) Progress
inherited
onTouchCancel(EventCallback handler) Progress
inherited
onTouchEnd(EventCallback handler) Progress
inherited
onTouchMove(EventCallback handler) Progress
inherited
onTouchStart(EventCallback handler) Progress
inherited
onTransitionEnd(EventCallback handler) Progress
inherited
onVolumeChange(EventCallback handler) Progress
inherited
onWheel(EventCallback handler) Progress
inherited
style(Map<String, String> style) Progress
inherited
tabIndex(int value) Progress
Sets the tab order index for keyboard navigation.
inherited
title(String value) Progress
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
value(num v) Progress

Operators

operator ==(Object other) bool
The equality operator.
inherited