Ruby class final

Inheritance

Constructors

Ruby({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Ruby
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Ruby
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Ruby
Hides the element from screen readers.
inherited
ariaLabel(String value) Ruby
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Ruby
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Ruby
inherited
data(String key, String value) Ruby
Sets a custom data attribute.
inherited
hidden([bool h = true]) Ruby
Hides the element from display.
inherited
id(String id) Ruby
Sets the element's unique identifier.
inherited
lang(String value) Ruby
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Ruby
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Ruby
inherited
onAnimationIteration(EventCallback handler) Ruby
inherited
onAnimationStart(EventCallback handler) Ruby
inherited
onBlur(EventCallback handler) Ruby
inherited
onCanPlay(EventCallback handler) Ruby
inherited
onCanPlayThrough(EventCallback handler) Ruby
inherited
onChange(EventCallback handler) Ruby
inherited
onClick(EventCallback handler) Ruby
inherited
onContextMenu(EventCallback handler) Ruby
inherited
onCopy(EventCallback handler) Ruby
inherited
onCut(EventCallback handler) Ruby
inherited
onDoubleClick(EventCallback handler) Ruby
inherited
onDrag(EventCallback handler) Ruby
inherited
onDragEnd(EventCallback handler) Ruby
inherited
onDragEnter(EventCallback handler) Ruby
inherited
onDragLeave(EventCallback handler) Ruby
inherited
onDragOver(EventCallback handler) Ruby
inherited
onDragStart(EventCallback handler) Ruby
inherited
onDrop(EventCallback handler) Ruby
inherited
onEnded(EventCallback handler) Ruby
inherited
onFocus(EventCallback handler) Ruby
inherited
onFocusIn(EventCallback handler) Ruby
inherited
onFocusOut(EventCallback handler) Ruby
inherited
onInput(EventCallback handler) Ruby
inherited
onKeyDown(EventCallback handler) Ruby
inherited
onKeyPress(EventCallback handler) Ruby
inherited
onKeyUp(EventCallback handler) Ruby
inherited
onLoadedData(EventCallback handler) Ruby
inherited
onLoadedMetadata(EventCallback handler) Ruby
inherited
onMouseDown(EventCallback handler) Ruby
inherited
onMouseEnter(EventCallback handler) Ruby
inherited
onMouseLeave(EventCallback handler) Ruby
inherited
onMouseMove(EventCallback handler) Ruby
inherited
onMouseOut(EventCallback handler) Ruby
inherited
onMouseOver(EventCallback handler) Ruby
inherited
onMouseUp(EventCallback handler) Ruby
inherited
onPaste(EventCallback handler) Ruby
inherited
onPause(EventCallback handler) Ruby
inherited
onPlay(EventCallback handler) Ruby
inherited
onPointerCancel(EventCallback handler) Ruby
inherited
onPointerDown(EventCallback handler) Ruby
inherited
onPointerEnter(EventCallback handler) Ruby
inherited
onPointerLeave(EventCallback handler) Ruby
inherited
onPointerMove(EventCallback handler) Ruby
inherited
onPointerUp(EventCallback handler) Ruby
inherited
onReset(EventCallback handler) Ruby
inherited
onScroll(EventCallback handler) Ruby
inherited
onSelect(EventCallback handler) Ruby
inherited
onSubmit(EventCallback handler) Ruby
inherited
onTimeUpdate(EventCallback handler) Ruby
inherited
onTouchCancel(EventCallback handler) Ruby
inherited
onTouchEnd(EventCallback handler) Ruby
inherited
onTouchMove(EventCallback handler) Ruby
inherited
onTouchStart(EventCallback handler) Ruby
inherited
onTransitionEnd(EventCallback handler) Ruby
inherited
onVolumeChange(EventCallback handler) Ruby
inherited
onWheel(EventCallback handler) Ruby
inherited
style(Map<String, String> style) Ruby
inherited
tabIndex(int value) Ruby
Sets the tab order index for keyboard navigation.
inherited
title(String value) Ruby
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited