Section class final

Inheritance

Constructors

Section({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Section
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Section
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Section
Hides the element from screen readers.
inherited
ariaLabel(String value) Section
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Section
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Section
inherited
data(String key, String value) Section
Sets a custom data attribute.
inherited
hidden([bool h = true]) Section
Hides the element from display.
inherited
id(String id) Section
Sets the element's unique identifier.
inherited
lang(String value) Section
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Section
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Section
inherited
onAnimationIteration(EventCallback handler) Section
inherited
onAnimationStart(EventCallback handler) Section
inherited
onBlur(EventCallback handler) Section
inherited
onCanPlay(EventCallback handler) Section
inherited
onCanPlayThrough(EventCallback handler) Section
inherited
onChange(EventCallback handler) Section
inherited
onClick(EventCallback handler) Section
inherited
onContextMenu(EventCallback handler) Section
inherited
onCopy(EventCallback handler) Section
inherited
onCut(EventCallback handler) Section
inherited
onDoubleClick(EventCallback handler) Section
inherited
onDrag(EventCallback handler) Section
inherited
onDragEnd(EventCallback handler) Section
inherited
onDragEnter(EventCallback handler) Section
inherited
onDragLeave(EventCallback handler) Section
inherited
onDragOver(EventCallback handler) Section
inherited
onDragStart(EventCallback handler) Section
inherited
onDrop(EventCallback handler) Section
inherited
onEnded(EventCallback handler) Section
inherited
onFocus(EventCallback handler) Section
inherited
onFocusIn(EventCallback handler) Section
inherited
onFocusOut(EventCallback handler) Section
inherited
onInput(EventCallback handler) Section
inherited
onKeyDown(EventCallback handler) Section
inherited
onKeyPress(EventCallback handler) Section
inherited
onKeyUp(EventCallback handler) Section
inherited
onLoadedData(EventCallback handler) Section
inherited
onLoadedMetadata(EventCallback handler) Section
inherited
onMouseDown(EventCallback handler) Section
inherited
onMouseEnter(EventCallback handler) Section
inherited
onMouseLeave(EventCallback handler) Section
inherited
onMouseMove(EventCallback handler) Section
inherited
onMouseOut(EventCallback handler) Section
inherited
onMouseOver(EventCallback handler) Section
inherited
onMouseUp(EventCallback handler) Section
inherited
onPaste(EventCallback handler) Section
inherited
onPause(EventCallback handler) Section
inherited
onPlay(EventCallback handler) Section
inherited
onPointerCancel(EventCallback handler) Section
inherited
onPointerDown(EventCallback handler) Section
inherited
onPointerEnter(EventCallback handler) Section
inherited
onPointerLeave(EventCallback handler) Section
inherited
onPointerMove(EventCallback handler) Section
inherited
onPointerUp(EventCallback handler) Section
inherited
onReset(EventCallback handler) Section
inherited
onScroll(EventCallback handler) Section
inherited
onSelect(EventCallback handler) Section
inherited
onSubmit(EventCallback handler) Section
inherited
onTimeUpdate(EventCallback handler) Section
inherited
onTouchCancel(EventCallback handler) Section
inherited
onTouchEnd(EventCallback handler) Section
inherited
onTouchMove(EventCallback handler) Section
inherited
onTouchStart(EventCallback handler) Section
inherited
onTransitionEnd(EventCallback handler) Section
inherited
onVolumeChange(EventCallback handler) Section
inherited
onWheel(EventCallback handler) Section
inherited
style(Map<String, String> style) Section
inherited
tabIndex(int value) Section
Sets the tab order index for keyboard navigation.
inherited
title(String value) Section
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited