Small class final

Inheritance

Constructors

Small({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Small
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Small
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Small
Hides the element from screen readers.
inherited
ariaLabel(String value) Small
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Small
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Small
inherited
data(String key, String value) Small
Sets a custom data attribute.
inherited
hidden([bool h = true]) Small
Hides the element from display.
inherited
id(String id) Small
Sets the element's unique identifier.
inherited
lang(String value) Small
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Small
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Small
inherited
onAnimationIteration(EventCallback handler) Small
inherited
onAnimationStart(EventCallback handler) Small
inherited
onBlur(EventCallback handler) Small
inherited
onCanPlay(EventCallback handler) Small
inherited
onCanPlayThrough(EventCallback handler) Small
inherited
onChange(EventCallback handler) Small
inherited
onClick(EventCallback handler) Small
inherited
onContextMenu(EventCallback handler) Small
inherited
onCopy(EventCallback handler) Small
inherited
onCut(EventCallback handler) Small
inherited
onDoubleClick(EventCallback handler) Small
inherited
onDrag(EventCallback handler) Small
inherited
onDragEnd(EventCallback handler) Small
inherited
onDragEnter(EventCallback handler) Small
inherited
onDragLeave(EventCallback handler) Small
inherited
onDragOver(EventCallback handler) Small
inherited
onDragStart(EventCallback handler) Small
inherited
onDrop(EventCallback handler) Small
inherited
onEnded(EventCallback handler) Small
inherited
onFocus(EventCallback handler) Small
inherited
onFocusIn(EventCallback handler) Small
inherited
onFocusOut(EventCallback handler) Small
inherited
onInput(EventCallback handler) Small
inherited
onKeyDown(EventCallback handler) Small
inherited
onKeyPress(EventCallback handler) Small
inherited
onKeyUp(EventCallback handler) Small
inherited
onLoadedData(EventCallback handler) Small
inherited
onLoadedMetadata(EventCallback handler) Small
inherited
onMouseDown(EventCallback handler) Small
inherited
onMouseEnter(EventCallback handler) Small
inherited
onMouseLeave(EventCallback handler) Small
inherited
onMouseMove(EventCallback handler) Small
inherited
onMouseOut(EventCallback handler) Small
inherited
onMouseOver(EventCallback handler) Small
inherited
onMouseUp(EventCallback handler) Small
inherited
onPaste(EventCallback handler) Small
inherited
onPause(EventCallback handler) Small
inherited
onPlay(EventCallback handler) Small
inherited
onPointerCancel(EventCallback handler) Small
inherited
onPointerDown(EventCallback handler) Small
inherited
onPointerEnter(EventCallback handler) Small
inherited
onPointerLeave(EventCallback handler) Small
inherited
onPointerMove(EventCallback handler) Small
inherited
onPointerUp(EventCallback handler) Small
inherited
onReset(EventCallback handler) Small
inherited
onScroll(EventCallback handler) Small
inherited
onSelect(EventCallback handler) Small
inherited
onSubmit(EventCallback handler) Small
inherited
onTimeUpdate(EventCallback handler) Small
inherited
onTouchCancel(EventCallback handler) Small
inherited
onTouchEnd(EventCallback handler) Small
inherited
onTouchMove(EventCallback handler) Small
inherited
onTouchStart(EventCallback handler) Small
inherited
onTransitionEnd(EventCallback handler) Small
inherited
onVolumeChange(EventCallback handler) Small
inherited
onWheel(EventCallback handler) Small
inherited
style(Map<String, String> style) Small
inherited
tabIndex(int value) Small
Sets the tab order index for keyboard navigation.
inherited
title(String value) Small
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited