Svg class final

Inheritance

Constructors

Svg({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Svg
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Svg
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Svg
Hides the element from screen readers.
inherited
ariaLabel(String value) Svg
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Svg
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Svg
inherited
data(String key, String value) Svg
Sets a custom data attribute.
inherited
height(String h) Svg
hidden([bool h = true]) Svg
Hides the element from display.
inherited
id(String id) Svg
Sets the element's unique identifier.
inherited
lang(String value) Svg
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Svg
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Svg
inherited
onAnimationIteration(EventCallback handler) Svg
inherited
onAnimationStart(EventCallback handler) Svg
inherited
onBlur(EventCallback handler) Svg
inherited
onCanPlay(EventCallback handler) Svg
inherited
onCanPlayThrough(EventCallback handler) Svg
inherited
onChange(EventCallback handler) Svg
inherited
onClick(EventCallback handler) Svg
inherited
onContextMenu(EventCallback handler) Svg
inherited
onCopy(EventCallback handler) Svg
inherited
onCut(EventCallback handler) Svg
inherited
onDoubleClick(EventCallback handler) Svg
inherited
onDrag(EventCallback handler) Svg
inherited
onDragEnd(EventCallback handler) Svg
inherited
onDragEnter(EventCallback handler) Svg
inherited
onDragLeave(EventCallback handler) Svg
inherited
onDragOver(EventCallback handler) Svg
inherited
onDragStart(EventCallback handler) Svg
inherited
onDrop(EventCallback handler) Svg
inherited
onEnded(EventCallback handler) Svg
inherited
onFocus(EventCallback handler) Svg
inherited
onFocusIn(EventCallback handler) Svg
inherited
onFocusOut(EventCallback handler) Svg
inherited
onInput(EventCallback handler) Svg
inherited
onKeyDown(EventCallback handler) Svg
inherited
onKeyPress(EventCallback handler) Svg
inherited
onKeyUp(EventCallback handler) Svg
inherited
onLoadedData(EventCallback handler) Svg
inherited
onLoadedMetadata(EventCallback handler) Svg
inherited
onMouseDown(EventCallback handler) Svg
inherited
onMouseEnter(EventCallback handler) Svg
inherited
onMouseLeave(EventCallback handler) Svg
inherited
onMouseMove(EventCallback handler) Svg
inherited
onMouseOut(EventCallback handler) Svg
inherited
onMouseOver(EventCallback handler) Svg
inherited
onMouseUp(EventCallback handler) Svg
inherited
onPaste(EventCallback handler) Svg
inherited
onPause(EventCallback handler) Svg
inherited
onPlay(EventCallback handler) Svg
inherited
onPointerCancel(EventCallback handler) Svg
inherited
onPointerDown(EventCallback handler) Svg
inherited
onPointerEnter(EventCallback handler) Svg
inherited
onPointerLeave(EventCallback handler) Svg
inherited
onPointerMove(EventCallback handler) Svg
inherited
onPointerUp(EventCallback handler) Svg
inherited
onReset(EventCallback handler) Svg
inherited
onScroll(EventCallback handler) Svg
inherited
onSelect(EventCallback handler) Svg
inherited
onSubmit(EventCallback handler) Svg
inherited
onTimeUpdate(EventCallback handler) Svg
inherited
onTouchCancel(EventCallback handler) Svg
inherited
onTouchEnd(EventCallback handler) Svg
inherited
onTouchMove(EventCallback handler) Svg
inherited
onTouchStart(EventCallback handler) Svg
inherited
onTransitionEnd(EventCallback handler) Svg
inherited
onVolumeChange(EventCallback handler) Svg
inherited
onWheel(EventCallback handler) Svg
inherited
style(Map<String, String> style) Svg
inherited
tabIndex(int value) Svg
Sets the tab order index for keyboard navigation.
inherited
title(String value) Svg
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
viewBox(String vb) Svg
width(String w) Svg
xmlns(String ns) Svg

Operators

operator ==(Object other) bool
The equality operator.
inherited