Dir enum

Text direction for bidirectional text.

Inheritance
Available extensions

Values

ltr → const Dir

Left-to-right (default for most languages).

const Dir('ltr')
rtl → const Dir

Right-to-left (Arabic, Hebrew, etc.).

const Dir('rtl')
auto → const Dir

Let browser decide based on content.

const Dir('auto')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Dir>
A constant List of the values in this enum, in order of their declaration.