Sandbox enum

Sandbox permissions for iframes.

Inheritance
Available extensions

Values

allowForms → const Sandbox

Allow form submission.

const Sandbox('allow-forms')
allowModals → const Sandbox

Allow modal dialogs.

const Sandbox('allow-modals')
allowOrientationLock → const Sandbox

Allow orientation lock.

const Sandbox('allow-orientation-lock')
allowPointerLock → const Sandbox

Allow pointer lock API.

const Sandbox('allow-pointer-lock')
allowPopups → const Sandbox

Allow popups.

const Sandbox('allow-popups')
allowPopupsToEscapeSandbox → const Sandbox

Allow popups to escape sandbox.

const Sandbox('allow-popups-to-escape-sandbox')
allowPresentation → const Sandbox

Allow presentation API.

const Sandbox('allow-presentation')
allowSameOrigin → const Sandbox

Allow same-origin access (DANGEROUS if combined with scripts).

const Sandbox('allow-same-origin')
allowScripts → const Sandbox

Allow JavaScript execution.

const Sandbox('allow-scripts')
allowTopNavigation → const Sandbox

Allow top-level navigation.

const Sandbox('allow-top-navigation')
allowTopNavigationByUserActivation → const Sandbox

Allow top navigation by user activation only.

const Sandbox('allow-top-navigation-by-user-activation')
allowDownloads → const Sandbox

Allow downloads.

const Sandbox('allow-downloads')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Sandbox>
A constant List of the values in this enum, in order of their declaration.