Scope enum

Table header cell scope.

Inheritance
Available extensions

Values

row → const Scope

Header for a row.

const Scope('row')
col → const Scope

Header for a column.

const Scope('col')
rowgroup → const Scope

Header for a row group.

const Scope('rowgroup')
colgroup → const Scope

Header for a column group.

const Scope('colgroup')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Scope>
A constant List of the values in this enum, in order of their declaration.