Col class final

Inheritance

Constructors

Col({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Col
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Col
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Col
Hides the element from screen readers.
inherited
ariaLabel(String value) Col
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Col
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Col
inherited
data(String key, String value) Col
Sets a custom data attribute.
inherited
hidden([bool h = true]) Col
Hides the element from display.
inherited
id(String id) Col
Sets the element's unique identifier.
inherited
lang(String value) Col
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Col
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Col
inherited
onAnimationIteration(EventCallback handler) Col
inherited
onAnimationStart(EventCallback handler) Col
inherited
onBlur(EventCallback handler) Col
inherited
onCanPlay(EventCallback handler) Col
inherited
onCanPlayThrough(EventCallback handler) Col
inherited
onChange(EventCallback handler) Col
inherited
onClick(EventCallback handler) Col
inherited
onContextMenu(EventCallback handler) Col
inherited
onCopy(EventCallback handler) Col
inherited
onCut(EventCallback handler) Col
inherited
onDoubleClick(EventCallback handler) Col
inherited
onDrag(EventCallback handler) Col
inherited
onDragEnd(EventCallback handler) Col
inherited
onDragEnter(EventCallback handler) Col
inherited
onDragLeave(EventCallback handler) Col
inherited
onDragOver(EventCallback handler) Col
inherited
onDragStart(EventCallback handler) Col
inherited
onDrop(EventCallback handler) Col
inherited
onEnded(EventCallback handler) Col
inherited
onFocus(EventCallback handler) Col
inherited
onFocusIn(EventCallback handler) Col
inherited
onFocusOut(EventCallback handler) Col
inherited
onInput(EventCallback handler) Col
inherited
onKeyDown(EventCallback handler) Col
inherited
onKeyPress(EventCallback handler) Col
inherited
onKeyUp(EventCallback handler) Col
inherited
onLoadedData(EventCallback handler) Col
inherited
onLoadedMetadata(EventCallback handler) Col
inherited
onMouseDown(EventCallback handler) Col
inherited
onMouseEnter(EventCallback handler) Col
inherited
onMouseLeave(EventCallback handler) Col
inherited
onMouseMove(EventCallback handler) Col
inherited
onMouseOut(EventCallback handler) Col
inherited
onMouseOver(EventCallback handler) Col
inherited
onMouseUp(EventCallback handler) Col
inherited
onPaste(EventCallback handler) Col
inherited
onPause(EventCallback handler) Col
inherited
onPlay(EventCallback handler) Col
inherited
onPointerCancel(EventCallback handler) Col
inherited
onPointerDown(EventCallback handler) Col
inherited
onPointerEnter(EventCallback handler) Col
inherited
onPointerLeave(EventCallback handler) Col
inherited
onPointerMove(EventCallback handler) Col
inherited
onPointerUp(EventCallback handler) Col
inherited
onReset(EventCallback handler) Col
inherited
onScroll(EventCallback handler) Col
inherited
onSelect(EventCallback handler) Col
inherited
onSubmit(EventCallback handler) Col
inherited
onTimeUpdate(EventCallback handler) Col
inherited
onTouchCancel(EventCallback handler) Col
inherited
onTouchEnd(EventCallback handler) Col
inherited
onTouchMove(EventCallback handler) Col
inherited
onTouchStart(EventCallback handler) Col
inherited
onTransitionEnd(EventCallback handler) Col
inherited
onVolumeChange(EventCallback handler) Col
inherited
onWheel(EventCallback handler) Col
inherited
span(int s) Col
style(Map<String, String> style) Col
inherited
tabIndex(int value) Col
Sets the tab order index for keyboard navigation.
inherited
title(String value) Col
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited