Input class final

Inheritance

Constructors

Input({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Input
no setterinherited
tag String
finalinherited

Methods

accept(String a) Input
ariaDescribedBy(String id) Input
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Input
Hides the element from screen readers.
inherited
ariaLabel(String value) Input
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Input
Generic escape hatch for any attribute.
inherited
autocomplete(String a) Input
autofocus([bool af = true]) Input
call([List? children]) Morphic
Call operator for children
inherited
capture(String c) Input
checked([bool c = true]) Input
classes(String classes) Input
inherited
data(String key, String value) Input
Sets a custom data attribute.
inherited
disabled([bool d = true]) Input
form(String f) Input
formaction(String fa) Input
formenctype(String fe) Input
formmethod(String fm) Input
formnovalidate([bool fnv = true]) Input
formtarget(String ft) Input
hidden([bool h = true]) Input
Hides the element from display.
inherited
id(String id) Input
Sets the element's unique identifier.
inherited
lang(String value) Input
Sets the language of the element's content.
inherited
list(String l) Input
max(String m) Input
maxlength(int m) Input
min(String m) Input
minlength(int m) Input
multiple([bool m = true]) Input
name(String n) Input
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Input
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Input
inherited
onAnimationIteration(EventCallback handler) Input
inherited
onAnimationStart(EventCallback handler) Input
inherited
onBlur(EventCallback handler) Input
inherited
onCanPlay(EventCallback handler) Input
inherited
onCanPlayThrough(EventCallback handler) Input
inherited
onChange(EventCallback handler) Input
inherited
onClick(EventCallback handler) Input
inherited
onContextMenu(EventCallback handler) Input
inherited
onCopy(EventCallback handler) Input
inherited
onCut(EventCallback handler) Input
inherited
onDoubleClick(EventCallback handler) Input
inherited
onDrag(EventCallback handler) Input
inherited
onDragEnd(EventCallback handler) Input
inherited
onDragEnter(EventCallback handler) Input
inherited
onDragLeave(EventCallback handler) Input
inherited
onDragOver(EventCallback handler) Input
inherited
onDragStart(EventCallback handler) Input
inherited
onDrop(EventCallback handler) Input
inherited
onEnded(EventCallback handler) Input
inherited
onFocus(EventCallback handler) Input
inherited
onFocusIn(EventCallback handler) Input
inherited
onFocusOut(EventCallback handler) Input
inherited
onInput(EventCallback handler) Input
inherited
onKeyDown(EventCallback handler) Input
inherited
onKeyPress(EventCallback handler) Input
inherited
onKeyUp(EventCallback handler) Input
inherited
onLoadedData(EventCallback handler) Input
inherited
onLoadedMetadata(EventCallback handler) Input
inherited
onMouseDown(EventCallback handler) Input
inherited
onMouseEnter(EventCallback handler) Input
inherited
onMouseLeave(EventCallback handler) Input
inherited
onMouseMove(EventCallback handler) Input
inherited
onMouseOut(EventCallback handler) Input
inherited
onMouseOver(EventCallback handler) Input
inherited
onMouseUp(EventCallback handler) Input
inherited
onPaste(EventCallback handler) Input
inherited
onPause(EventCallback handler) Input
inherited
onPlay(EventCallback handler) Input
inherited
onPointerCancel(EventCallback handler) Input
inherited
onPointerDown(EventCallback handler) Input
inherited
onPointerEnter(EventCallback handler) Input
inherited
onPointerLeave(EventCallback handler) Input
inherited
onPointerMove(EventCallback handler) Input
inherited
onPointerUp(EventCallback handler) Input
inherited
onReset(EventCallback handler) Input
inherited
onScroll(EventCallback handler) Input
inherited
onSelect(EventCallback handler) Input
inherited
onSubmit(EventCallback handler) Input
inherited
onTimeUpdate(EventCallback handler) Input
inherited
onTouchCancel(EventCallback handler) Input
inherited
onTouchEnd(EventCallback handler) Input
inherited
onTouchMove(EventCallback handler) Input
inherited
onTouchStart(EventCallback handler) Input
inherited
onTransitionEnd(EventCallback handler) Input
inherited
onVolumeChange(EventCallback handler) Input
inherited
onWheel(EventCallback handler) Input
inherited
pattern(String p) Input
placeholder(String text) Input
readonly([bool r = true]) Input
required([bool r = true]) Input
size(int s) Input
step(String s) Input
style(Map<String, String> style) Input
inherited
tabIndex(int value) Input
Sets the tab order index for keyboard navigation.
inherited
title(String value) Input
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
type(InputType t) Input
value(String val) Input

Operators

operator ==(Object other) bool
The equality operator.
inherited