Meta class final

Inheritance

Constructors

Meta({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Meta
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Meta
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Meta
Hides the element from screen readers.
inherited
ariaLabel(String value) Meta
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Meta
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
charset(String c) Meta
classes(String classes) Meta
inherited
content(String c) Meta
data(String key, String value) Meta
Sets a custom data attribute.
inherited
hidden([bool h = true]) Meta
Hides the element from display.
inherited
httpEquiv(String he) Meta
id(String id) Meta
Sets the element's unique identifier.
inherited
lang(String value) Meta
Sets the language of the element's content.
inherited
name(String n) Meta
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Meta
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Meta
inherited
onAnimationIteration(EventCallback handler) Meta
inherited
onAnimationStart(EventCallback handler) Meta
inherited
onBlur(EventCallback handler) Meta
inherited
onCanPlay(EventCallback handler) Meta
inherited
onCanPlayThrough(EventCallback handler) Meta
inherited
onChange(EventCallback handler) Meta
inherited
onClick(EventCallback handler) Meta
inherited
onContextMenu(EventCallback handler) Meta
inherited
onCopy(EventCallback handler) Meta
inherited
onCut(EventCallback handler) Meta
inherited
onDoubleClick(EventCallback handler) Meta
inherited
onDrag(EventCallback handler) Meta
inherited
onDragEnd(EventCallback handler) Meta
inherited
onDragEnter(EventCallback handler) Meta
inherited
onDragLeave(EventCallback handler) Meta
inherited
onDragOver(EventCallback handler) Meta
inherited
onDragStart(EventCallback handler) Meta
inherited
onDrop(EventCallback handler) Meta
inherited
onEnded(EventCallback handler) Meta
inherited
onFocus(EventCallback handler) Meta
inherited
onFocusIn(EventCallback handler) Meta
inherited
onFocusOut(EventCallback handler) Meta
inherited
onInput(EventCallback handler) Meta
inherited
onKeyDown(EventCallback handler) Meta
inherited
onKeyPress(EventCallback handler) Meta
inherited
onKeyUp(EventCallback handler) Meta
inherited
onLoadedData(EventCallback handler) Meta
inherited
onLoadedMetadata(EventCallback handler) Meta
inherited
onMouseDown(EventCallback handler) Meta
inherited
onMouseEnter(EventCallback handler) Meta
inherited
onMouseLeave(EventCallback handler) Meta
inherited
onMouseMove(EventCallback handler) Meta
inherited
onMouseOut(EventCallback handler) Meta
inherited
onMouseOver(EventCallback handler) Meta
inherited
onMouseUp(EventCallback handler) Meta
inherited
onPaste(EventCallback handler) Meta
inherited
onPause(EventCallback handler) Meta
inherited
onPlay(EventCallback handler) Meta
inherited
onPointerCancel(EventCallback handler) Meta
inherited
onPointerDown(EventCallback handler) Meta
inherited
onPointerEnter(EventCallback handler) Meta
inherited
onPointerLeave(EventCallback handler) Meta
inherited
onPointerMove(EventCallback handler) Meta
inherited
onPointerUp(EventCallback handler) Meta
inherited
onReset(EventCallback handler) Meta
inherited
onScroll(EventCallback handler) Meta
inherited
onSelect(EventCallback handler) Meta
inherited
onSubmit(EventCallback handler) Meta
inherited
onTimeUpdate(EventCallback handler) Meta
inherited
onTouchCancel(EventCallback handler) Meta
inherited
onTouchEnd(EventCallback handler) Meta
inherited
onTouchMove(EventCallback handler) Meta
inherited
onTouchStart(EventCallback handler) Meta
inherited
onTransitionEnd(EventCallback handler) Meta
inherited
onVolumeChange(EventCallback handler) Meta
inherited
onWheel(EventCallback handler) Meta
inherited
property(String p) Meta
style(Map<String, String> style) Meta
inherited
tabIndex(int value) Meta
Sets the tab order index for keyboard navigation.
inherited
title(String value) Meta
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited