Param class final

Inheritance

Constructors

Param({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Param
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Param
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Param
Hides the element from screen readers.
inherited
ariaLabel(String value) Param
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Param
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Param
inherited
data(String key, String value) Param
Sets a custom data attribute.
inherited
hidden([bool h = true]) Param
Hides the element from display.
inherited
id(String id) Param
Sets the element's unique identifier.
inherited
lang(String value) Param
Sets the language of the element's content.
inherited
name(String n) Param
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Param
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Param
inherited
onAnimationIteration(EventCallback handler) Param
inherited
onAnimationStart(EventCallback handler) Param
inherited
onBlur(EventCallback handler) Param
inherited
onCanPlay(EventCallback handler) Param
inherited
onCanPlayThrough(EventCallback handler) Param
inherited
onChange(EventCallback handler) Param
inherited
onClick(EventCallback handler) Param
inherited
onContextMenu(EventCallback handler) Param
inherited
onCopy(EventCallback handler) Param
inherited
onCut(EventCallback handler) Param
inherited
onDoubleClick(EventCallback handler) Param
inherited
onDrag(EventCallback handler) Param
inherited
onDragEnd(EventCallback handler) Param
inherited
onDragEnter(EventCallback handler) Param
inherited
onDragLeave(EventCallback handler) Param
inherited
onDragOver(EventCallback handler) Param
inherited
onDragStart(EventCallback handler) Param
inherited
onDrop(EventCallback handler) Param
inherited
onEnded(EventCallback handler) Param
inherited
onFocus(EventCallback handler) Param
inherited
onFocusIn(EventCallback handler) Param
inherited
onFocusOut(EventCallback handler) Param
inherited
onInput(EventCallback handler) Param
inherited
onKeyDown(EventCallback handler) Param
inherited
onKeyPress(EventCallback handler) Param
inherited
onKeyUp(EventCallback handler) Param
inherited
onLoadedData(EventCallback handler) Param
inherited
onLoadedMetadata(EventCallback handler) Param
inherited
onMouseDown(EventCallback handler) Param
inherited
onMouseEnter(EventCallback handler) Param
inherited
onMouseLeave(EventCallback handler) Param
inherited
onMouseMove(EventCallback handler) Param
inherited
onMouseOut(EventCallback handler) Param
inherited
onMouseOver(EventCallback handler) Param
inherited
onMouseUp(EventCallback handler) Param
inherited
onPaste(EventCallback handler) Param
inherited
onPause(EventCallback handler) Param
inherited
onPlay(EventCallback handler) Param
inherited
onPointerCancel(EventCallback handler) Param
inherited
onPointerDown(EventCallback handler) Param
inherited
onPointerEnter(EventCallback handler) Param
inherited
onPointerLeave(EventCallback handler) Param
inherited
onPointerMove(EventCallback handler) Param
inherited
onPointerUp(EventCallback handler) Param
inherited
onReset(EventCallback handler) Param
inherited
onScroll(EventCallback handler) Param
inherited
onSelect(EventCallback handler) Param
inherited
onSubmit(EventCallback handler) Param
inherited
onTimeUpdate(EventCallback handler) Param
inherited
onTouchCancel(EventCallback handler) Param
inherited
onTouchEnd(EventCallback handler) Param
inherited
onTouchMove(EventCallback handler) Param
inherited
onTouchStart(EventCallback handler) Param
inherited
onTransitionEnd(EventCallback handler) Param
inherited
onVolumeChange(EventCallback handler) Param
inherited
onWheel(EventCallback handler) Param
inherited
style(Map<String, String> style) Param
inherited
tabIndex(int value) Param
Sets the tab order index for keyboard navigation.
inherited
title(String value) Param
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
value(String v) Param

Operators

operator ==(Object other) bool
The equality operator.
inherited