Polyline class final

Inheritance

Constructors

Polyline({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Polyline
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Polyline
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Polyline
Hides the element from screen readers.
inherited
ariaLabel(String value) Polyline
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Polyline
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Polyline
inherited
data(String key, String value) Polyline
Sets a custom data attribute.
inherited
hidden([bool h = true]) Polyline
Hides the element from display.
inherited
id(String id) Polyline
Sets the element's unique identifier.
inherited
lang(String value) Polyline
Sets the language of the element's content.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Polyline
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Polyline
inherited
onAnimationIteration(EventCallback handler) Polyline
inherited
onAnimationStart(EventCallback handler) Polyline
inherited
onBlur(EventCallback handler) Polyline
inherited
onCanPlay(EventCallback handler) Polyline
inherited
onCanPlayThrough(EventCallback handler) Polyline
inherited
onChange(EventCallback handler) Polyline
inherited
onClick(EventCallback handler) Polyline
inherited
onContextMenu(EventCallback handler) Polyline
inherited
onCopy(EventCallback handler) Polyline
inherited
onCut(EventCallback handler) Polyline
inherited
onDoubleClick(EventCallback handler) Polyline
inherited
onDrag(EventCallback handler) Polyline
inherited
onDragEnd(EventCallback handler) Polyline
inherited
onDragEnter(EventCallback handler) Polyline
inherited
onDragLeave(EventCallback handler) Polyline
inherited
onDragOver(EventCallback handler) Polyline
inherited
onDragStart(EventCallback handler) Polyline
inherited
onDrop(EventCallback handler) Polyline
inherited
onEnded(EventCallback handler) Polyline
inherited
onFocus(EventCallback handler) Polyline
inherited
onFocusIn(EventCallback handler) Polyline
inherited
onFocusOut(EventCallback handler) Polyline
inherited
onInput(EventCallback handler) Polyline
inherited
onKeyDown(EventCallback handler) Polyline
inherited
onKeyPress(EventCallback handler) Polyline
inherited
onKeyUp(EventCallback handler) Polyline
inherited
onLoadedData(EventCallback handler) Polyline
inherited
onLoadedMetadata(EventCallback handler) Polyline
inherited
onMouseDown(EventCallback handler) Polyline
inherited
onMouseEnter(EventCallback handler) Polyline
inherited
onMouseLeave(EventCallback handler) Polyline
inherited
onMouseMove(EventCallback handler) Polyline
inherited
onMouseOut(EventCallback handler) Polyline
inherited
onMouseOver(EventCallback handler) Polyline
inherited
onMouseUp(EventCallback handler) Polyline
inherited
onPaste(EventCallback handler) Polyline
inherited
onPause(EventCallback handler) Polyline
inherited
onPlay(EventCallback handler) Polyline
inherited
onPointerCancel(EventCallback handler) Polyline
inherited
onPointerDown(EventCallback handler) Polyline
inherited
onPointerEnter(EventCallback handler) Polyline
inherited
onPointerLeave(EventCallback handler) Polyline
inherited
onPointerMove(EventCallback handler) Polyline
inherited
onPointerUp(EventCallback handler) Polyline
inherited
onReset(EventCallback handler) Polyline
inherited
onScroll(EventCallback handler) Polyline
inherited
onSelect(EventCallback handler) Polyline
inherited
onSubmit(EventCallback handler) Polyline
inherited
onTimeUpdate(EventCallback handler) Polyline
inherited
onTouchCancel(EventCallback handler) Polyline
inherited
onTouchEnd(EventCallback handler) Polyline
inherited
onTouchMove(EventCallback handler) Polyline
inherited
onTouchStart(EventCallback handler) Polyline
inherited
onTransitionEnd(EventCallback handler) Polyline
inherited
onVolumeChange(EventCallback handler) Polyline
inherited
onWheel(EventCallback handler) Polyline
inherited
points(String value) Polyline
style(Map<String, String> style) Polyline
inherited
tabIndex(int value) Polyline
Sets the tab order index for keyboard navigation.
inherited
title(String value) Polyline
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited