Source class final

Inheritance

Constructors

Source({Object? key})

Properties

hashCode int
The hash code for this object.
no setterinherited
isVoid bool
finalinherited
key Object?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
self Source
no setterinherited
tag String
finalinherited

Methods

ariaDescribedBy(String id) Source
References another element by ID for accessible description.
inherited
ariaHidden([bool h = true]) Source
Hides the element from screen readers.
inherited
ariaLabel(String value) Source
Sets the accessible label for screen readers.
inherited
attr(String name, Attribute value) Source
Generic escape hatch for any attribute.
inherited
call([List? children]) Morphic
Call operator for children
inherited
classes(String classes) Source
inherited
data(String key, String value) Source
Sets a custom data attribute.
inherited
height(int h) Source
hidden([bool h = true]) Source
Hides the element from display.
inherited
id(String id) Source
Sets the element's unique identifier.
inherited
lang(String value) Source
Sets the language of the element's content.
inherited
media(String m) Source
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on(String event, EventCallback handler) Source
Generic event handler for custom or less common events.
inherited
onAnimationEnd(EventCallback handler) Source
inherited
onAnimationIteration(EventCallback handler) Source
inherited
onAnimationStart(EventCallback handler) Source
inherited
onBlur(EventCallback handler) Source
inherited
onCanPlay(EventCallback handler) Source
inherited
onCanPlayThrough(EventCallback handler) Source
inherited
onChange(EventCallback handler) Source
inherited
onClick(EventCallback handler) Source
inherited
onContextMenu(EventCallback handler) Source
inherited
onCopy(EventCallback handler) Source
inherited
onCut(EventCallback handler) Source
inherited
onDoubleClick(EventCallback handler) Source
inherited
onDrag(EventCallback handler) Source
inherited
onDragEnd(EventCallback handler) Source
inherited
onDragEnter(EventCallback handler) Source
inherited
onDragLeave(EventCallback handler) Source
inherited
onDragOver(EventCallback handler) Source
inherited
onDragStart(EventCallback handler) Source
inherited
onDrop(EventCallback handler) Source
inherited
onEnded(EventCallback handler) Source
inherited
onFocus(EventCallback handler) Source
inherited
onFocusIn(EventCallback handler) Source
inherited
onFocusOut(EventCallback handler) Source
inherited
onInput(EventCallback handler) Source
inherited
onKeyDown(EventCallback handler) Source
inherited
onKeyPress(EventCallback handler) Source
inherited
onKeyUp(EventCallback handler) Source
inherited
onLoadedData(EventCallback handler) Source
inherited
onLoadedMetadata(EventCallback handler) Source
inherited
onMouseDown(EventCallback handler) Source
inherited
onMouseEnter(EventCallback handler) Source
inherited
onMouseLeave(EventCallback handler) Source
inherited
onMouseMove(EventCallback handler) Source
inherited
onMouseOut(EventCallback handler) Source
inherited
onMouseOver(EventCallback handler) Source
inherited
onMouseUp(EventCallback handler) Source
inherited
onPaste(EventCallback handler) Source
inherited
onPause(EventCallback handler) Source
inherited
onPlay(EventCallback handler) Source
inherited
onPointerCancel(EventCallback handler) Source
inherited
onPointerDown(EventCallback handler) Source
inherited
onPointerEnter(EventCallback handler) Source
inherited
onPointerLeave(EventCallback handler) Source
inherited
onPointerMove(EventCallback handler) Source
inherited
onPointerUp(EventCallback handler) Source
inherited
onReset(EventCallback handler) Source
inherited
onScroll(EventCallback handler) Source
inherited
onSelect(EventCallback handler) Source
inherited
onSubmit(EventCallback handler) Source
inherited
onTimeUpdate(EventCallback handler) Source
inherited
onTouchCancel(EventCallback handler) Source
inherited
onTouchEnd(EventCallback handler) Source
inherited
onTouchMove(EventCallback handler) Source
inherited
onTouchStart(EventCallback handler) Source
inherited
onTransitionEnd(EventCallback handler) Source
inherited
onVolumeChange(EventCallback handler) Source
inherited
onWheel(EventCallback handler) Source
inherited
sizes(String s) Source
src(String s) Source
srcset(String ss) Source
style(Map<String, String> style) Source
inherited
tabIndex(int value) Source
Sets the tab order index for keyboard navigation.
inherited
title(String value) Source
Sets the element's title (tooltip text).
inherited
toString() String
A string representation of this object.
inherited
type(String t) Source
width(int w) Source

Operators

operator ==(Object other) bool
The equality operator.
inherited