RenderContext class

Constructors

RenderContext()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

currentComponent Component?
no setter
runtime ComponentRuntime
no setter

Static Methods

run<T>(ComponentRuntime runtime, T fn()) → T
runWithComponent<T>(Component component, T fn()) → T