RouterComponent class final
Constructors
- RouterComponent({required Router router, required Component layout(Component page)})
Properties
- attached ↔ bool
-
getter/setter pairinherited
- componentRuntime → ComponentRuntime?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- layoutBuilder → Component Function(Component page)
-
final
- router → Router
-
final
- runtime → ComponentRuntime
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
→ List<
Stylesheet> -
no setterinherited
Methods
-
attach(
ComponentRuntime runtime) → void -
inherited
-
detach(
) → void -
inherited
-
morph(
void updater()) → void -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onMorph(
) → void -
inherited
-
onMount(
) → void -
render(
) → Morphic -
override
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited