Base class for all Pulsar components.
Components are long-lived objects that produce Morphic trees. When state changes via setState(), the component morphs its output.
- Implementers
Constructors
Properties
- attached ↔ bool
-
getter/setter pair
- componentRuntime → ComponentRuntime?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtime → ComponentRuntime
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
→ List<
Stylesheet> -
no setter
Methods
-
attach(
ComponentRuntime runtime) → void -
detach(
) → void -
morph(
void updater()) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onMorph(
) → void -
render(
) → Morphic -
toString(
) → String -
A string representation of this object.
inherited
-
update(
) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited