Target enum
Link and form target contexts.
Provides type-safe values for the target attribute of <a> and <form> elements.
Usage:
A().href('/page').target(Target.blank)
Form().action('/submit').target(Target.self)
Values
- blank → const Target
-
Opens in a new tab or window.
const Target('_blank') - self → const Target
-
Opens in the same frame (default behavior).
const Target('_self') - parent → const Target
-
Opens in the parent frame.
const Target('_parent') - top → const Target
-
Opens in the full window, breaking out of all frames.
const Target('_top')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
The HTML attribute value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited