AreaShape enum
Area shape types for image maps.
Values
- rect → const AreaShape
-
Rectangle (coords: left, top, right, bottom).
const AreaShape('rect') - circle → const AreaShape
-
Circle (coords: center-x, center-y, radius).
const AreaShape('circle') - poly → const AreaShape
-
Polygon (coords: x1, y1, x2, y2, ...).
const AreaShape('poly') - default_ → const AreaShape
-
Default area (entire image).
const AreaShape('default')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited