InputMode enum
Input mode hints for virtual keyboards.
Values
- none → const InputMode
-
No virtual keyboard (for custom input methods).
const InputMode('none') - text → const InputMode
-
Standard text keyboard.
const InputMode('text') - decimal → const InputMode
-
Decimal numeric keyboard (with decimal separator).
const InputMode('decimal') - numeric → const InputMode
-
Numeric keyboard (integers only).
const InputMode('numeric') - tel → const InputMode
-
Telephone number keyboard.
const InputMode('tel') - search → const InputMode
-
Search-optimized keyboard.
const InputMode('search') - email → const InputMode
-
Email-optimized keyboard (with @ key).
const InputMode('email') - url → const InputMode
-
URL-optimized keyboard (with / and .com keys).
const InputMode('url')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited