ReferrerPolicy enum
Referrer policy for links and resources.
Values
- noReferrer → const ReferrerPolicy
-
Never send referrer.
const ReferrerPolicy('no-referrer') - noReferrerWhenDowngrade → const ReferrerPolicy
-
Send full URL for same-origin, no referrer for cross-origin when downgrading.
const ReferrerPolicy('no-referrer-when-downgrade') - origin → const ReferrerPolicy
-
Send only origin (no path).
const ReferrerPolicy('origin') - originWhenCrossOrigin → const ReferrerPolicy
-
Send full URL for same-origin, origin for cross-origin.
const ReferrerPolicy('origin-when-cross-origin') - sameOrigin → const ReferrerPolicy
-
Send referrer only for same-origin requests.
const ReferrerPolicy('same-origin') - strictOrigin → const ReferrerPolicy
-
Send origin for same-origin, no referrer when downgrading.
const ReferrerPolicy('strict-origin') - strictOriginWhenCrossOrigin → const ReferrerPolicy
-
Send full URL for same-origin, origin for cross-origin when not downgrading.
const ReferrerPolicy('strict-origin-when-cross-origin') - unsafeUrl → const ReferrerPolicy
-
Always send full URL (unsafe).
const ReferrerPolicy('unsafe-url')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ReferrerPolicy> - A constant List of the values in this enum, in order of their declaration.