Rel enum
Link relationship types.
Values
- alternate → const Rel
-
Alternate version of the document.
const Rel('alternate') -
Author of the document.
const Rel('author') - bookmark → const Rel
-
Bookmark (permanent URL for the document).
const Rel('bookmark') - canonical → const Rel
-
Canonical URL for the document.
const Rel('canonical') - dnsPrefetch → const Rel
-
DNS prefetch hint.
const Rel('dns-prefetch') - external → const Rel
-
Link to external site.
const Rel('external') - help → const Rel
-
Help documentation.
const Rel('help') - icon → const Rel
-
Icon for the page.
const Rel('icon') - license → const Rel
-
License for the content.
const Rel('license') - next → const Rel
-
Next document in sequence.
const Rel('next') - nofollow → const Rel
-
Do not follow this link (for SEO).
const Rel('nofollow') - noopener → const Rel
-
Do not open in new context.
const Rel('noopener') - noreferrer → const Rel
-
Do not send referrer.
const Rel('noreferrer') - pingback → const Rel
-
Pingback URL.
const Rel('pingback') - preconnect → const Rel
-
Preconnect to origin.
const Rel('preconnect') - prefetch → const Rel
-
Prefetch resource.
const Rel('prefetch') - preload → const Rel
-
Preload resource.
const Rel('preload') - prev → const Rel
-
Previous document in sequence.
const Rel('prev') - search → const Rel
-
Search interface for the site.
const Rel('search') - stylesheet → const Rel
-
Stylesheet link.
const Rel('stylesheet') - tag → const Rel
-
Tag/keyword for the document.
const Rel('tag')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited