TrackKind enum
Track kinds for video/audio subtitles and captions.
Values
- subtitles → const TrackKind
-
Subtitles (translation for those who understand audio).
const TrackKind('subtitles') - captions → const TrackKind
-
Captions (transcription + sound effects for deaf/hard of hearing).
const TrackKind('captions') - descriptions → const TrackKind
-
Descriptions (text descriptions of visual content for blind users).
const TrackKind('descriptions') - chapters → const TrackKind
-
Chapter markers.
const TrackKind('chapters') - metadata → const TrackKind
-
Metadata track (not displayed).
const TrackKind('metadata')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited