ComponentRuntime class final
Constructors
- ComponentRuntime(Renderer renderer)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- renderer → Renderer
-
final
- rootComponent ↔ Component?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styles → StyleRegistry
-
final
Methods
-
mount(
Component root) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerComponentDomNode(
Component component, Node dom) → void - Stores the root DOM node for a component. Called by createDom once the Element for a component's root is created.
-
registerComponentTree(
Component component, Morphic tree) → void - Stores the Morphic tree for a component. Called by resolveNode as soon as a component's render output is resolved.
-
requestUpdateFor(
Component component) → void -
Granular update — re-renders and diffs only
component's subtree. -
toString(
) → String -
A string representation of this object.
inherited
-
unmount(
) → void -
unregisterComponent(
Component component) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited